SupremeCourt

Opinions-(2014-2015)

- About the Supreme Court
- Attorney Search
- Commission on Judicial Tenure and Discipline
- Contact Information
- Disciplinary Board
- Domestic Violence Training and Monitoring Unit
- Ethics Advisory Panel
- Forms
- Frequently Asked Questions
- Mandatory Continuing Legal Education
- Supreme Court Rides the Circuit

# Supreme Court

#### Published Opinions 2014 - 2015 Term

Document Library Title Link | Name
--- | ---
Allan M. Shine et al. v. Charles Moreau et al., Nos. 13-249, 13-248, 13-249 (June 18, 2015) | 13-247, 248, 249
These consolidated cases came before this Court on appeal from a decision of the Providence County Superior Court, in which it made three distinct holdings. First, the Superior Court granted the Central Falls Receiver’s motion for partial summary judgment, holding that the Receiver, who was appointed to Central Falls pursuant to the terms of chapter 9 of title 45 of the Rhode Island General Laws (the Financial Stability Act), was entitled to reimbursement for his attorneys’ fees; the Superior Court determined that that reimbursement was to be furnished by Central Falls Mayor Charles Moreau (the Mayor) and the members of the City Council for the City of Central Falls (the City Council) (collectively the Appellants), in their individual capacities. The Superior Court, consequently, denied the counter-motion for summary judgment filed by the Appellants relative to the same issue. The Superior Court’s second holding was to the effect that the Mayor was not entitled to indemnification from the Receiver for “all losses, costs, expenses, and damages—including attorney’s fees and court costs—arising out of” the instant cases, thus denying the Mayor’s partial summary judgment motion and granting the counter-motion for summary judgment filed by the Receiver relative to that issue. Lastly, the Superior Court denied a motion for advance of attorneys’ fees to Attorney Lawrence L. Goldberg. On appeal, the Appellants contend that all three of the hearing justice’s holdings were made in error. The Supreme Court held that the section of the Financial Stability Act at issue did not entitle the Receiver to reimbursement of his attorneys’ fees because it did not specifically call for payment of attorneys’ fees as an exception to normal practice pursuant to “the American rule.” The Court then held that the Mayor was entitled to indemnification of his attorneys’ fees and costs because, in view of the unique set of factual circumstances presented in these cases, the Mayor was acting in his official capacity when he challenged the constitutionality of the Financial Stability Act and defended against the action for declaratory and injunctive relief that was filed by the Receiver. Lastly, the Court held that Attorney Goldberg, who represented the City Council, was entitled to his attorneys’ fees, since the City Council’s resolutions allowing for the hiring of outside counsel should have been recognized as being in full force and effect under the exceptional circumstances presented in these cases. Accordingly, the Court vacated the decision of the Superior Court in all respects and remanded the cases to that tribunal for a determination of the amount of attorneys’ fees still at issue.
In re Jah-nell B., No. 14-38 (June 17, 2015) | 14-38
The respondent, Clifton Barr, appealed from a decree entered in Family Court terminating his parental rights to his son, Jah-nell. The respondent contended that the trial justice erred in finding that he was unfit because clear and convincing evidence of his parental unfitness was absent from the record. The respondent also argued that the state failed to prove that the Department of Children, Youth and Families (DCYF) made reasonable efforts to reunify him with his son prior to filing the petition to terminate his parental rights. In reviewing this termination of parental rights, the Supreme Court examined the record to ascertain whether legal and competent evidence existed to support the findings of the trial justice. The trial justice found the respondent unfit pursuant to G.L. 1956 § 15-7-7(a)(1), (3), and (4). The trial justice also found that DCYF made reasonable efforts to reunify the respondent with his son. After careful review of the record, the Supreme Court was satisfied that legally competent evidence existed to support the trial justice’s findings. Accordingly, the Supreme Court affirmed the decree of the Family Court.
Peerless Insurance Company v. Denise Luppe; Peerless Insurance Company v. Christopher Henderson, Nos. 14-99, 14-100 (June 17, 2015) | 14-99, 14-100
The defendants in this declaratory judgment action, Christopher Henderson and Denise Luppe, appealed from a final judgment entered in Washington County Superior Court in favor of the plaintiff, Peerless Insurance Company. The defendants are the divorced parents of a minor child, Maya Henderson, who suffered injuries when she was bitten by her father’s dog, in her father’s house. Acting as Maya’s next best friend, Ms. Luppe brought a personal injury suit against Mr. Henderson, who attempted to avail himself of his Peerless homeowner’s insurance policy. Peerless brought this action seeking a declaration that Maya was a resident of her father’s household and that, therefore, Peerless need not defend claims as to Mr. Henderson’s personal liability because the policy excludes coverage for injuries to fellow residents of the household. The Superior Court found, on undisputed facts, that Maya was a resident of her father’s household and granted summary judgment on the issue in favor of Peerless. On appeal, the Supreme Court was asked to address the definition of resident as it pertains to insurance policies. The defendants contended that Maya was a resident of her mother’s household only. In a matter of first impression, the Supreme Court held that the definition of resident set forth in Aetna Life and Casualty Co. v. Carrera, 577 A.2d 980, 985 (R.I. 1990) applied not only to uninsured motorist insurance, but across all contexts of insurance. In Carrera, we gave the definition of resident: “In order to determine if a person is a resident of a particular household, the court must consider whether in the totality of the circumstances that person maintains a physical presence in the household with intent to remain for more than a mere transitory period * * * .” Id. Stated succinctly, the Supreme Court held that one who has a personal presence in a home, with intent to remain so for more than a temporary period, is considered a resident of that home. Maya lived and slept at her father’s house twice a week, each week, in accordance with the couple’s custody agreement. Several of Maya’s personal belongings and items of clothing could be found in her father’s house. Family and friends visited Maya at her father’s house on these days. Importantly, the parents intended the arrangement to continue and it did indeed continue, even after the injuries sustained by Maya. The Supreme Court did not opine on Maya’s possible residency with her mother except to say that the fact that Maya may be a resident of her mother’s home does not make it impossible that she could also be a resident of her father’s home. Because Maya fit the definition of resident that the Supreme Court set forth in Carrera, a definition applicable across all insurance contexts, the summary judgment granted for the plaintiff, Peerless, was affirmed.
Western Reserve Life Assurance Co. of Ohio v. ADM Associates, LLC, No. 14-35 (June 17, 2015) | 14-35
On certification from the United States Court of Appeals for the First Circuit, the Supreme Court was presented with two questions. The first question asked whether an annuity policy with a death benefit would be infirm for want of an insurable interest when the owner and beneficiary of the annuity was a stranger to the annuitant. The Supreme Court held that G.L. 1956 § 27-4-27, which provides the statutory requirement that the beneficiary of a life insurance policy have an insurable interest in the insured, does not apply to an annuity policy with a death benefit because the statute applies only to life insurance policies. With respect to the common law insurable interest requirement, the Supreme Court held that the long-standing common law does not extend to annuity policies because the structure and function of life insurance policies are distinct from the characteristics of annuity policies. The Supreme Court also held that an annuity policy with a death benefit in which the annuitant is a stranger to the beneficiary is not a wagering contract and is therefore not void as a matter of public policy. The Supreme Court ultimately concluded that an annuity policy with a death benefit would not be infirm for want of an insurable interest when the owner and beneficiary of the annuity policy is a stranger to the annuitant. The second question considered whether an incontestability clause in an annuity policy that made the annuity incontestable from the date of the policy’s issuance would preclude civil litigation on the basis of a lack of an insurable interest. Pursuant to the Supreme Court’s long-established common law regarding the effect of, and purpose behind, incontestability clauses, the Supreme Court held that an incontestability clause that takes immediate effect is enforceable and precludes all causes of action that seek to invalidate the policy.
State v. Elizabeth Mendez, No. 13-13 (June 15, 2015) | 13-13
The defendant, Elizabeth Mendez, appealed from a Superior Court judgment of conviction for possession of more than five kilograms of marijuana. On appeal, the defendant contended: (1) that the trial justice erred in his supplemental jury instruction given in response to a question posed by the jury; (2) that the trial justice erred in denying the defendant’s motion for a new trial; and (3) that the defendant’s twenty-year sentence violated the Rhode Island Constitution. The Supreme Court held first that the defendant waived any argument which she may have had relative to the supplemental jury instruction because she failed to raise it in a timely manner before the trial justice. The Supreme Court next held that the trial justice correctly denied the defendant’s motion for a new trial, in light of his careful execution of the three-step analytical approach required in considering a motion for a new trial. Finally, the Supreme Court held that the matter of whether the defendant’s twenty-year sentence was violative of Article 1, Section 8 of the Rhode Island Constitution was not properly before the Court, because she had not made the requisite motion, pursuant to Rule 35 of the Superior Court Rules of Criminal Procedure, to review her sentence in the Superior Court. Accordingly, the Court affirmed the trial justice’s decision in all respects and upheld the defendant’s conviction.
Kayak Centre at Wickford Cove, LLC d/b/a Kayak Centre of Rhode Island v. Town of Narragansett et al., No. 14-168 (June 15, 2015) | 14-168
The plaintiff, Kayak Centre at Wickford Cove, LLC, appealed from a final judgment entered in favor of the defendants, the town of Narragansett and Narrow River Kayaks, LLC. The plaintiff was unsuccessful in winning a town concession contract to operate a paddle sports business on town-owned land at 94 Middlebridge Road. Narrow River was the current occupant of that property and a bidder for the concession. Arguing that it was wrongly denied the award, the plaintiff’s complaint asked for (1) a declaratory judgment that the town had violated sections of the general laws controlling the award of municipal contracts, G.L. 1956 chapter 55 of title 45, and (2) injunctive relief against the town to prevent it from rebidding the concession contract. The town conducted an advertised bidding process that asked for paddle sports businesses to bid and specify the amount they would be willing to pay to the town annually to operate on the property. After reviewing the two bids received, the town’s purchasing agent concluded that Kayak Centre was the most qualified bidder and recommended that the town council award it the concession contract. However, at the subsequent town council meeting, when a motion was made to award the contract to Kayak Centre, the town council voted three to one to reject the motion. The town council then voted three to one to reject all bids and commence the bidding process again, to reformulate a bid package that would better ascertain which bidder was in the best interest of the town. On appeal, the plaintiff maintained that the trial justice made two errors that warrant reversal: (1) it was error to fail to apply § 45-55-5 and deny declaratory relief, and (2) it was error for the trial justice to deny injunctive relief because she concluded that the standards of fairness outlined in our prior cases did not apply to this particular dispute. On review, the Supreme Court saw no error in the trial justice’s ruling that § 45-55-5 did not apply to the situation because the language of the statute is clear and unambiguous. The Court held that § 45-55-5, as written, applies to the “purchases” of a municipal entity, not a concession agreement that generates revenue. However, the Court held that the good faith standard of Gilbane Building Co. v. Board of Trustees of State Colleges, 107 R.I. 295, 299-300, 267 A.2d 396, 399 (1970), applied in the absence of a specific statute. Because the trial justice concluded that the Gilbane standard did not apply, she consequently did not address whether the town acted “corruptly or in bad faith, or so unreasonably or so arbitrarily as to be guilty of a palpable abuse of discretion.” Gilbane, 107 R.I. at 399, 267 A.2d at 300 (citing Slocum v. City of Medford, 18 N.E.2d 1013, 1015 (Mass. 1939)). Because the Supreme Court disagreed with the trial justice’s determination as to the applicability of the Gilbane standard, the case must be remanded to the trial justice for findings of fact and conclusions of law on that issue. For these reasons, the Supreme Court affirmed in part and reversed in part the decision of the Superior Court, vacated the judgment, and remanded to the Superior Court for further proceedings.
FIA Card Services, N.A. v. James D. Pichette; HSBC Bank Nevada, N.A. v. Robert L. Cournoyer; Discover Bank v. Diana L. O’Brien-Auty, Nos. 12-272, 13-156, 13,157 (June 8, 2015) | 12-272, 13-156, 13-157
This set of appeals emanated from the activities of three attorneys who authored pleadings, but did not disclose their respective identities, on behalf of pro se defendants in three separate debt collection cases, a practice colloquially known as ghostwriting. These appeals presented the Supreme Court with two issues of first impression: (1) whether Rule 11 of the Superior Court Rules of Civil Procedure applies to an attorney who neither signed a pleading nor entered his or her appearance in the case; and (2) whether the anonymous preparation of pleadings for self-represented litigants is a permissible practice pursuant to the Supreme Court Rules of Professional Conduct. The hearing justices imposed sanctions on each attorney for drafting, but not signing, answers and objections to dispositive motions on behalf of the three pro se defendants. All three attorneys argued that Rule 11 did not apply to their respective situations because none had either signed the pleadings or entered an appearance. The Supreme Court held that the conduct of the three attorneys did not violate Rule 11 and, accordingly, vacated the sanctions imposed by the three Superior Court orders. The attorneys also argued that ghostwriting was a permissible form of limited-scope representation pursuant to Article V, Rule 1.2(c) of the Supreme Court Rules of Professional Conduct. The Supreme Court declared the policy in our courts to be as follows: An attorney may provide legal assistance to litigants appearing pro se before courts, provided the scope of the attorney’s representation is reasonable and the litigant gave informed consent. Such consent shall be in writing and shall set forth the nature and extent of the attorney-client relationship. An attorney, however, shall not assist a pro se litigant with the preparation of pleadings, motions, or other written submissions unless the attorney signs the document and discloses thereon his or her identity and the nature and extent of the assistance that he or she is providing to the tribunal and to all parties to the litigation. The attorney shall also indicate on the written document, if applicable, that his or her signature does not constitute an entry of appearance. Through an order, the Supreme Court invited comment from members of the bench, bar, and public on the subject of limited scope representation in general and the practice of ghostwriting in particular.
State v. Reynaldo Gomez, No. 14-146 (June 5, 2015) | 14-146
he defendant, Reynaldo Gomez, appealed from a Superior Court judgment of conviction after having been found guilty by a jury of second-degree sexual assault in violation of G.L. 1956 § 11-37-4(2). On appeal, the defendant contended that the trial justice erred in: (1) denying his motion for judgment of acquittal; (2) denying his motion for a new trial; and (3) allowing the complaining witness’s statements to a police officer at the scene into evidence under the excited-utterance exception to the hearsay rule. After a careful review of the record, the Supreme Court determined that the trial justice’s rulings, which the Court reviewed with deference, were proper. The Supreme Court found no error in the trial justice’s denial of the defendant’s motion for a new trial. The Supreme Court agreed with the trial justice’s denial of the defendant’s motion for judgment of acquittal because there was sufficient evidence of “force” within the meaning of the statute to sustain the defendant’s conviction for second-degree sexual assault. Lastly, the Supreme Court upheld the trial justice’s evidentiary ruling that hearsay statements made by the complaining witness nevertheless qualified as excited utterances. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
Medical Malpractice Joint Underwriting Association of Rhode Island v. Charlesgate Nursing Center, L.P., et al., No. 13-359 (June 5, 2015) | 13-359
This insurance-coverage dispute presented a novel legal question regarding an insurer’s duty to defend that emanated from a set of tragic circumstances involving the alleged sexual assault of a nursing home resident. The plaintiff, Medical Malpractice Joint Underwriting Association of Rhode Island (JUA), sought a declaratory judgment from the Superior Court to establish that it owed no duty to defend its insured, Charlesgate Nursing Center, L.P. (Charlesgate), two of Charlesgate’s general partners, and two of its employees (collectively Charlesgate defendants), against the allegations set forth in a separate civil action filed by the administrator of the estate of a former nursing home resident (estate’s complaint). The instant appeal stemmed from this declaratory-judgment action brought by the JUA; it is an appeal from the judgment denying its motion for summary judgment and granting the Charlesgate defendants’ cross-motion for summary judgment on their counterclaim for declaratory judgment. On appeal, the JUA contended that the Charlesgate defendants were not entitled to commercial general liability (CGL) coverage because the sexual assault alleged in the estate’s complaint did not constitute an “occurrence,” defined in the policy as an “accident.” The Charlesgate defendants asserted that the alleged negligence claims against them were an “occurrence” under the terms of the CGL coverage in the policy. The estate largely mirrored the argument of the Charlesgate defendants that the language in the estate’s complaint did allege an “occurrence” as defined in the JUA policy, based on the proximate cause of the injuries alleged. The issue of whether the JUA owes the Charlesgate defendants a duty to defend them in the estate’s underlying suit hinged on whether the facts alleged in the estate’s complaint constituted an “occurrence” to which the CGL coverage potentially applies. The Supreme Court determined that the JUA has a duty to defend the Charlesgate defendants against the claims of negligence set forth in the estate’s complaint. Accordingly, the Supreme Court affirmed the judgment of the Superior Court granting summary judgment in favor of the Charlesgate defendants and denying the JUA’s motion for summary judgment with regard to the declaratory-judgment count of the Charlesgate defendants’ counterclaim.
South County Post & Beam, Inc. v. Brian T. McMahon et al., Nos. 14-24, 25-25 (June 5, 2015) | 14-24, 25
This case emanated from the all-to-common scenario of an escalated billing dispute between property owners and a subcontractor hired to help construct a house. The defendants, Brian and Karen McMahon, engaged various construction companies to contribute to the project of building a house and barn on their Block Island property. The plaintiff, South County Post & Beam, Inc., was one of the subcontractors which worked on the project. The plaintiff filed a civil suit seeking payment for the work it had completed but for which it had not been paid. After a bench trial, a Superior Court justice entered judgment for the plaintiff on its claim of unjust enrichment, but judgment for the defendants on the plaintiff’s claims of breach of contract and book account. The trial justice also entered an order granting the plaintiff’s posttrial “Application for Taxation of Costs,” including fees for the expert witness who had testified on the plaintiff’s behalf. The defendants appealed from both the judgment and the order, and the Supreme Court consolidated the appeals. The Supreme Court first noted that, while the plaintiff had styled its cause of action as one for unjust enrichment, the plaintiff had actually sought to recover in quantum meruit, a distinct but closely related theory of restitution that ultimately required the plaintiff to prove the same set of elements. The Supreme Court upheld the judgment for the plaintiff, emphasizing the fact-specific nature of this cause of action, which ultimately came down to a balancing of the equities to determine whether it would have been unjust for the defendants to retain the value of the services that the plaintiff had rendered without paying the value thereof. The Supreme Court also noted that, because unjust enrichment and quantum meruit are treated as standalone causes of action, the presence or absence of an alternative adequate remedy at law is simply one of the factors to be considered in the balancing of the equities and is not determinative of whether the plaintiff could prevail as a matter of law. Regarding the order awarding costs of the action to the plaintiff, the Supreme Court held that the trial justice had erroneously included the costs of the plaintiff’s expert witness. Pursuant to G.L. 1956 § 9-17-22 and the Supreme Court’s past precedent, fees expended for expert witnesses are not recoverable as costs of an action. Accordingly, the Supreme Court affirmed the Superior Court’s judgment, but vacated and remanded the order.
State v. Justin Prout, No. 13-58 (June 5, 2015) | 13-58
The defendant, Justin Prout, appealed from a Superior Court judgment declaring him to be in violation of the terms of his probation and sentencing him to serve thirteen years of a previously imposed suspended sentence. In 2006, the defendant was convicted of breaking and entering, assault with a dangerous weapon, and simple assault. He was sentenced to serve ten years for breaking and entering, as well as a concurrent sentence of two years to serve and thirteen years suspended, with probation, for the felony assault. In 2012, while the defendant was incarcerated at the High Security Center of the Adult Correctional Institutions, an altercation occurred between the defendant and a correctional officer, Christian Torres, which resulted in significant injuries to Officer Torres. As a result of this altercation, the state initiated probation-violation proceedings regarding the suspended portion of the defendant’s sentence for felony assault. After a two-day hearing, the hearing justice found that the defendant had violated the terms of his probation by failing to keep the peace and remain of good behavior. Three correctional officers testified at the hearing, as did the defendant; the officers testified that the defendant had been the first aggressor in the altercation with Officer Torres, while the defendant maintained that Officer Torres had attacked him. The Supreme Court affirmed the judgment of the Superior Court. The Supreme Court noted that the hearing justice had thoroughly assessed the testimonial and documentary evidence presented at the hearing, and that he had issued a bench decision explaining why he was reasonably satisfied that the defendant had failed to keep the peace and remain of good behavior. The Supreme Court further explained that the hearing justice had found that the officers’ version of the altercation involving the defendant and Officer Torres was more credible than the version presented by the defendant. The Supreme Court found no reason to question the credibility determinations of the hearing justice and, accordingly, affirmed the adjudication of probation violation.
State v. Ramon Virola., No. 13-365 (June 4, 2015) | 13-365
The defendant, Ramon Virola, appealed from a “Judgment of Conviction and Commitment” dated July 3, 2013, entered after a jury found him guilty of four criminal counts related to a murder committed during the course of an attempted robbery. On appeal, the defendant contended that the trial justice erred in denying his motion for a new trial and in admitting certain witness testimony. Specifically, he posited that the testimony of three of the key witnesses at trial was not credible. The defendant further argued that the trial justice erred in admitting certain testimony because the testimony was not relevant and, even if it were relevant, the unfairly prejudicial nature of that testimony greatly outweighed its probative value, in violation of Rule 403 of the Rhode Island Rules of Evidence. The Supreme Court held that the trial justice properly applied the three-step analysis with respect to a motion for a new trial and did not err in: (1) ultimately concluding that he agreed with the jury’s verdict; and (2) denying the motion for a new trial. The Supreme Court also held that the trial justice did not abuse his discretion in allowing into evidence certain testimony because that testimony was relevant and its probative value was not greatly outweighed by any prejudice that may have resulted from its admission. Accordingly, the Court affirmed the Superior Court’s judgment of conviction and its denial of the defendant’s motion for a new trial.
In re Max M., No. 2014-312 (June 4, 2015) | 14-312
The respondent father, Eric M., appealed from a Family Court decree which terminated his parental rights with respect to his son, Max M. On appeal, the respondent argued that the record lacked clear and convincing proof of: (1) his unfitness as a parent; and (2) the reasonable efforts of the Department of Children, Youth and Families (DCYF) to reunify the respondent with his son. The Court analyzed the undisputed testimony presented at trial from a DCYF caseworker, a DCYF supervisor, and the respondent. The Court held that the just-referenced testimony provided an ample evidentiary basis for the trial justice’s finding that the respondent father was unfit to parent his son. Furthermore, the Court held that the trial justice properly found that DCYF made reasonable efforts at reunification by offering weekly visits and engaging in case planning with the respondent, and that it was the respondent’s own recalcitrance which precluded reunification with his son. Accordingly, the Supreme Court affirmed the Family Court decree terminating the respondent’s parental rights with respect to his son.
Joseph McNulty et al. v. Kristen Chip et al., No. 14-97 (June 4, 2015) | 14-97
The plaintiffs, Joseph and Elizabeth McNulty, appealed from a judgment of the Superior Court that granted the defendants’ motions for summary judgment dismissing all claims stemming from the plaintiffs’ purchase of their home. The defendant-seller resided at the property, which her parents owned, during her childhood and until she relocated for college, but claimed to not have known about significant flooding that occurred in 1998 after she had moved away. In 2002 the defendant-seller purchased the property from her parents and, in connection with that sale, did not receive a real estate disclosure form from her parents and did not inspect the property before she bought it. In 2004 the property was listed for sale and the defendant-seller completed and executed a real estate disclosure form, in which she indicated that there had been no previous flooding or water penetration at the property. Prior to executing a purchase and sales agreement, the plaintiffs had the property professionally inspected and were informed that there was evidence of water penetration, dampness, and water stains in the basement. Also, the plaintiffs alleged that, during the course of the inspection, the defendant-real estate agent allegedly said that there previously had been “maybe an inch or so” of water in the basement. The plaintiffs executed a purchase and sales agreement that contained the following disclaimer: “The Property is being sold in ‘AS IS’ condition and Buyer represents that it has not relied on the oral representations of the Seller, or the Broker(s) or their agents as to the character or quality of the Property.” In addition, the agreement provided that the plaintiffs had previously conducted their inspections. Weeks after the sale was finalized, but before the plaintiffs were able to move into the property, a heavy rainstorm caused major flooding and two or three feet of water accumulated in the basement. In the aftermath of the October 2005 flood, plaintiffs received a letter from the son of the developer of the neighborhood that explained that, since 1968, the area had been susceptible to significant flooding. The water problems persisted over the next several years, culminating in March 2010, when the plaintiffs experienced extensive flooding of the property. As a result, the plaintiffs filed suit seeking to recover for alleged misrepresentations under the theories of breach of contract, negligence, and fraud. The defendants moved for summary judgment and argued that the negligence claims were barred by the statute of limitations, the fraud claim was barred by the disclaimer contained in the purchase and sales agreement, and that the contract claims failed as a matter of law. After multiple hearings before two separate justices of the Superior Court, the defendants’ motions were granted. On appeal, the plaintiffs argued that the defendants waived their statute of limitations defense because they failed to raise it in their answer, or, in the alternative, that they were entitled to have the limitations period tolled. Also, the plaintiffs argued that genuine issues of material fact precluded judgment from entering on the fraud claim. The Supreme Court held that the hearing justice properly dismissed the plaintiffs’ negligence claims based on the statute of limitations. The Supreme Court explained that the defendants did not waive their statute of limitations defense because it was raised well in advance of trial, and that the plaintiffs were not entitled to have the limitations period tolled because after numerous water problems that occurred shortly after the purchase, they knew, or should have known in the exercise of reasonable diligence, that they were injured. Next, the Supreme Court held that the hearing justice erroneously dismissed the plaintiffs’ fraud claim based on the disclaimer contained in the purchase and sales agreement because it was not drawn with sufficient specificity. The Court also rejected the defendants’ arguments that, notwithstanding the absence of an effective disclaimer, the fraud claim failed because genuine issues of fact existed with respect to the defendants’ knowledge, or lack thereof, about the water problems. Finally, the Supreme Court held that summary judgment was properly granted as to the claim of breach of the implied warranty of good faith and fair dealing in light of the plaintiffs’ voluntary dismissal of their breach of contract claim. Accordingly, the Supreme Court affirmed the pretrial grants of summary judgment on the plaintiffs’ negligence and contract claims, but vacated the grant of summary judgment on the fraud claim.
Rhode Island Joint Reinsurance Association v. Manuel Rosario et al., No. 13-159 (June 4, 2015) | 13-159
This appeal resulted from an interpleader action brought by the Rhode Island Joint Reinsurance Association against multiple defendants for the purpose of determining the proper disposition of insurance proceeds, which were disbursed pursuant to an insurance policy covering mortgaged real property that was damaged by fire. The former homeowner and borrower, Reyna Bernard, as well as Manuel Rosario, appealed from a judgment of the Superior Court in favor of the loan servicer, Ocwen Loan Servicing, LLC. The Supreme Court affirmed the judgment of the Superior Court. While Bernard and Rosario alleged that the lender improperly conducted foreclosure proceedings against the insured property, the Supreme Court held that the propriety of the foreclosure was not at issue in this interpleader action. The Supreme Court further held that Bernard and Rosario were not entitled to the insurance proceeds pursuant to the terms of the mortgage, because the borrower had agreed to maintain fire insurance on the property with the lender named as a loss payee, the lender had exercised its statutory power of sale, and the amount of the insurance proceeds was less than the amount unpaid under the note.
Valerie L. Bremer v. William G. Bremer, Nos. 12-23, 12-239, 14-254 (May 29, 2015) | 12-237, 12-239, 14-254
Before the Court were three appeals filed by Valerie L. Bremer from various proceedings in the Family Court relative to her divorce from William G. Bremer. She appealed the assignment of William Bremer’s motion for clarification to the Family Court justice who had presided over the original divorce proceeding; the decision on the motion for clarification; and an order adjudging her in contempt for failure to comply with the final judgment of divorce. The Supreme Court held that the assignment of the case to a particular judicial officer was interlocutory and fell within the administrative powers of the Chief Judge of the Family Court. The Court likewise found no merit in Valerie Bremer’s contentions with regard to the motion for clarification or the order adjudging her in contempt. Accordingly, the Court affirmed the judgment of the Family Court in all respects.
City of Cranston v. International Brotherhood of Police Officers, Local 301, No. 2014-15 (May 29, 2015) | 14-15
This case came before the Supreme Court on April 29, 2015, on appeal by International Brotherhood of Police Officers, Local 301 (union), from a Superior Court order granting the City of Cranston’s (city) motion to vacate an arbitration award in the union’s favor. The city denied a Cranston police officer’s retirement after the officer completed nineteen years, six months and one day of service, instead of the twenty years required by state statute. The officer asserted that, according to the collective bargaining agreement (CBA), she was entitled to retire when she completed nineteen years, six months, and one day of service, as specified in the “round-up rule.” The city contended that, because the officer opted into the Municipal Employee Retirement System (MERS), state law required the officer to complete the full twenty years of service in order to retire. The matter proceeded to arbitration, and an arbitrator found that the officer was entitled to retire, according to the round-up rule, after completing less than twenty years of service. The city moved to vacate the arbitration award in the Superior Court, and a trial justice determined that the round-up rule contravened state law and vacated the arbitration award. Before the Supreme Court, the union asserted that the Superior Court justice erred in vacating the award and that the judgment should be vacated and the arbitration award confirmed. The Supreme Court determined that the decision of the arbitrator that a MERS member can utilize provisions in the CBA that contradict state law was improper and in excess of his authority. Accordingly, the Supreme Court affirmed the Superior Court judgment.
State v. Raymond A. Peltier, No. 13-310 (May 29, 2015) | 13-310
This case came before the Supreme Court pursuant to an order directing the parties to appear and show cause why the issues raised in this appeal should not summarily be decided. The defendant, Raymond A. Peltier (defendant), appeals from a judgment of conviction after a jury trial of one count of simple domestic assault. Before this Court, the defendant asserts that the trial justice erred when he allowed into evidence the fact that the defendant resisted arrest in this case, a complaint to which the defendant had entered a plea of nolo contendere immediately before the start of trial. The Supreme Court determined that the circumstances of the resisting- arrest charge appropriately were admitted because the facts surrounding the resisting-arrest charge were intricately interwoven with the domestic assault and because resisting arrest was indicative of the defendant’s consciousness of guilt. Accordingly, the Supreme Court affirmed the conviction.
In re Kristopher J., No. 14-206 (May 28, 2015) | 14-206
The respondent-father, Christopher Jimenez, was indicted for inflicting numerous injuries, over the span of several weeks, on his five-week-old daughter, Christina, resulting in the infant’s death. In response to the allegations lodged against the respondent with respect to his daughter, the Department of Children, Youth, and Families (DCYF) filed a petition to terminate the respondent’s parental rights to his other child, a one-year-old son named Kristopher. The petition for termination of parental rights came to trial in the Family Court, over the span of eight days, and featured several witnesses who interacted with the respondent, the injured child, and the child’s extended family. A treating physician testified that the child’s numerous severe injuries, including brain swelling, broken ribs, and fractures to her legs and arms, were not explained by the respondent’s statements to doctors. A child protective investigator from DCYF testified that, in an interview, the respondent told her that he was the caretaker for the child the evening in question. Then, DCYF called the respondent to the witness stand to testify, but he asserted his Fifth Amendment right and refused to answer any questions about the night his daughter sustained her fatal injuries. Because the termination petition is a civil matter, the trial justice was allowed to draw negative inferences because of this refusal to testify. After taking the matter under consideration, the trial justice issued a lengthy and comprehensive decision and accompanying decree, which terminated the respondent’s parental rights to his son. On appeal, the respondent argues that it was error for the trial justice to terminate his parental rights because, even though he concedes that the trial justice had “compelling evidence before her that Christina suffered fatal injuries,” she nonetheless lacked clear and convincing evidence of the culpability of the respondent as the cause of those injuries. The respondent urged the Supreme Court to consider In re Adner G., 925 A.2d 951, 960-62 (R.I. 2007), a case in which we vacated the termination of parental rights. The Supreme Court did not find the In re Adner G. case persuasive, since in the instant case there was no evidence that any other caretaker had access to the child on the night of the fatal injuries. The Court instead found the case of In re Chester J., 754 A.2d 772, 777-78 (R.I. 2000), better suited to the facts at hand. The respondent was unable or unwilling to explain the cause of injuries to his child while the child was in his care. The Court found no legal error in the trial justice’s findings, based on compelling testimony and the respondent’s refusal to testify to any details, that the respondent was responsible for his daughter’s injuries. Therefore, because of the respondent’s cruel and abusive conduct towards his daughter, the trial justice appropriately terminated the respondent’s parental rights to his other child.
State v. John Whiting, No. 12-362 (May 27, 2015) | 12-362
The defendant appealed from his convictions of larceny over $500 in violation of G.L. 1956 §§ 11-41-1 and 11-41-5 and soliciting another to receive stolen goods in violation of G.L. 1956 § 11-1-9. After the defendant had been indicted, but prior to the commencement of his trial, § 11-41-5 was amended to increase the threshold for felony larceny from $500 to $1,500. On appeal, the defendant argued that, in light of the amendment, the larceny count should be amended and the solicitation charge should be dismissed, or in the alternative, amended. The Supreme Court rejected the defendant’s argument, holding that there was no indication that the amendment to § 11-41-5 was intended to be applied retroactively. Further, the Supreme Court determined that the general savings clause, G.L. 1956 § 43-3-23, permitted the prosecution and sentencing of the defendant in accordance with the pre-amendment version of § 11-41-5.
Jean Ho-Rath et al. v. Rhode Island Hospital et al., Nos. 12-208, 12-211 (May 19, 2015) | 12-208, 211
This case required the Supreme Court to answer two questions of first impression relating to G.L. 1956 § 9-1-14.1(1), which contains the statute of limitations for the medical malpractice claims of minors. The plaintiffs, Jean and Bunsan Ho-Rath, initiated a medical malpractice suit in 2010 on behalf of their minor daughter, Yendee, who was born in 1998 with a genetic disorder. The plaintiffs brought suit on behalf of Yendee, as well as on behalf of themselves for loss of consortium, against numerous medical organizations and professionals, alleging negligence in the diagnosis and treatment relating to Yendee’s genetic disorder. Certain defendants filed motions to dismiss on the basis that the plaintiffs’ claims were untimely pursuant to the applicable statute of limitations. The Superior Court granted the defendants’ motions to dismiss, finding that all of the plaintiffs’ claims were barred by the statute of limitations set forth in § 9-1-14.1(1) because they were filed more than three years after the incident that gave rise to the cause of action. The hearing justice reserved Yendee’s right to file a future suit on her own behalf upon reaching the age of majority. The Supreme Court affirmed the judgment of the Superior Court. The Supreme Court held that § 9-1-14.1(1) provides a minor plaintiff in a medical malpractice action with two options. First, the minor’s parent or guardian may file suit on the minor’s behalf within three years of the occurrence or reasonable discovery of alleged malpractice. Alternatively, if the minor’s parent or guardian fails to file suit on the minor’s behalf within those three years, then the minor may file suit on his or her own behalf, but not until he or she reaches the age of majority. Upon reaching the age of majority, he or she has three years within which to file the action. Accordingly, the Supreme Court held that the plaintiffs’ claims were untimely pursuant to § 9-1-14.1(1) because they had been filed more than three years after the alleged occurrence of malpractice, but that Yendee retained the right to file suit on her own behalf upon reaching the age of majority. Next, the Supreme Court held that a parent’s claim for loss of consortium in a medical malpractice case should be tolled alongside the minor’s claim from which it derives—meaning that, if no suit is filed on behalf of the minor within three years of the injury, the parents may avail themselves of the three-year limitations period that opens for the minor upon reaching the age of majority pursuant to § 9-1-14.1(1). Thus, the plaintiffs were not foreclosed from appending their derivative claims to a future suit brought by Yendee after she attains the age of majority.
State of Rhode Island Department of Corrections v. Rhode Island Brotherhood of Correctional Officers, No. 13-142 (May 14, 2015) | 13-142
This case came before the Rhode Island Supreme Court on appeal by the defendant, Rhode Island Brotherhood of Correctional Officers (RIBCO), from a Superior Court order granting a motion by the plaintiff, Department of Corrections (DOC), to vacate an arbitration award. The DOC had terminated a sworn officer for accompanying a fellow officer who was smoking marijuana in a DOC vehicle while working at a security post—while armed with a loaded shotgun and handgun—and for continuously lying to the Rhode Island State Police and the DOC investigation officers about his being in the vehicle and observing the wrongful conduct. The RIBCO filed a grievance on behalf of the officer in accordance with its Collective Bargaining Agreement (CBA), contending that the officer was terminated without just cause. The matter proceeded to arbitration; and, after the arbitration hearing, the arbitrator found that the officer’s termination lacked just cause and fashioned his own remedy. The DOC subsequently filed a motion to vacate the arbitration award. The trial justice vacated the arbitration award and determined (1) that the dispute was arbitrable; and (2) that the arbitrator exceeded his authority and reached an irrational result. The RIBCO appealed the trial justice’s decision to vacate the arbitration award to the Supreme Court, contending that the trial justice erred in vacating the arbitration award. After thorough review of the record and the arguments of the parties, the Supreme Court affirmed the trial justice’s determination that the dispute was arbitrable and that the arbitrator had exceeded his authority.
State v. Robert Austin, No. 13-77 (May 1, 2015) | 13-77
The defendant, Robert Austin, appealed from his conviction on one count of second-degree sexual assault. On appeal, the defendant challenged the trial justice’s pretrial denial of his motion to suppress the complaining witness’s out-of-court identification because the identification procedure was unnecessarily suggestive. He also asserted that the trial justice’s denial of his motion for a new trial was in error. Lastly, the defendant contended that the trial justice erred in denying his request for a specific set of jury instructions. The Supreme Court held that the trial justice correctly denied the defendant’s motion to suppress the out-of-court identification. The Court reasoned that the photo array was not unnecessarily suggestive in light of the fact that nearly all of the men in the photographs matched the general characteristics described by the complaining witness. Observing that the trial justice undertook the proper analysis for challenges to the weight of the evidence, the Court held that he was not clearly wrong in denying the defendant’s motion for a new trial. Finally, the Court concluded that the jury instructions given by the trial justice adequately covered the law concerning eyewitness identification. The Court acknowledged that the trial justice did not use all of the defendant’s specifically requested language, but that he clearly conveyed the essence of the requested instruction. Accordingly, the Court affirmed the judgment of conviction.
William A. Bettez v. Robert A. Bettez et al., No. 13-305 (April 29, 2015) | 13-305
In this will contest, William A. Bettez (plaintiff), a son of Rudolph T. Bettez (the decedent), appealed a Superior Court grant of summary judgment dismissing the plaintiff’s appeal and sustaining the decision of the Probate Court of the Town of Scituate to admit the decedent’s will to probate. On appeal, the plaintiff argued that the trial justice erred by finding that there was no question of fact with regard to his claim of undue influence. Specifically, the plaintiff maintained that the existence of a purported conflict of interest and the existence of another judicial proceeding involving many of the same parties should have prevented the entry of summary judgment. The Supreme Court held that the plaintiff’s claims were unsubstantiated and that the plaintiff had failed to carry his burden to set forth evidence showing that a genuine issue of material fact existed in order to avoid the entry of summary judgment. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
Hines Road, LLC v. Neil Hall, in his capacity as Building Inspector for the Town of Cumberland et al., No. 13-257 (April 28, 2015) | 13-257
The petitioners, Joseph and Angitta DiOrio, appealed from a Superior Court order denying their motion to intervene (pursuant to Rule 24 of the Superior Court Rules of Civil Procedure) in a civil action between the plaintiff, Hines Road, LLC, and the defendants, collectively referred to as the Town of Cumberland. In support of their appeal, the petitioners argued: (1) that the Supreme Court’s opinion in Caran v. Freda, 108 R.I. 748, 279 A.2d 405 (1971), permitted them to intervene as of right; (2) that the hearing justice abused his discretion in finding that the petitioners’ interest in the litigation between the plaintiff and the Town of Cumberland was “contingent;” and (3) that the petitioners’ failure to appeal an earlier decision by the Town of Cumberland Zoning Board of Review should not have been “held against” them. The Supreme Court found these arguments unpersuasive, holding: (1) that the hearing justice did not abuse his discretion when he found that the petitioners failed to demonstrate that they fulfilled the four-factor test for intervention as of right pursuant to Rule 24(a)(2) as described by the Supreme Court in Tonetti Enterprises, LLC v. Mendon Road Leasing Corp., 943 A.2d 1063, 1072-73 (R.I. 2008); and (2) that the hearing justice did not abuse his discretion when he found that the petitioners failed to offer any arguments that demonstrated that they should be allowed to intervene on a permissive basis. Accordingly, the Supreme Court affirmed the Superior Court’s denial of the petitioners’ motion to intervene.
State v. Jack Gregson, No. 14-51 (April 27, 2015) | 14-51
Following a jury trial in the Superior Court, the defendant, Jack Gregson (defendant) was convicted of one count of first-degree sexual assault; one count of second-degree sexual assault; two counts of assault with intent to commit second-degree sexual assault; and two counts of indecent solicitation of a minor. On appeal, the defendant contended that the trial justice committed two errors of law that required the Supreme Court to vacate those convictions: (1) the denial of the defendant’s motion for a bill of particulars; and (2) the denial of the defendant’s motion for a new trial. After a thorough examination of the record, the Supreme Court determined that the trial justice did not err in denying the defendant’s motion for a bill of particulars and that the trial justice did not err in denying the defendant’s motion for a new trial. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
Norman T. Gadomski, Jr. v. Joseph H. Tavares, Chief of Police for the City of East Providence, No. 14-72 (April 22, 2015) | 14-72
Norman T. Gadomski, Jr., petitioned the Supreme Court for review of a decision of the City of East Providence’s police chief, Joseph H. Tavares, denying Gadomski’s application for a license to carry a concealed weapon pursuant to G.L. 1956 § 11-47-11. In Gadomski’s application, he indicated that he wanted the license for both work and nonwork reasons. He also disclosed that he had been arraigned twice as an adult on misdemeanor charges that were ultimately dismissed. Additionally, Gadomski supplemented his application with documentation showing that he was a gun collector and had firearm permits from other states. Gadomski was interviewed by Tavares regarding the application. Later, after prodding by Gadomski, a decision was rendered which denied the application. The decision stated that Gadomski had not satisfied the criteria for issuance of a license, specifically indicating that Gadomski’s prior arrests were a factor. The Supreme Court noted that the City of East Providence’s weapons carry policy, which undergirded Tavares’s decision, inappropriately combined the standards of §§ 11-47-11 and 11-47-18. Because of this error, in addition to the erroneous reliance on Gadomski’s remote, largely irrelevant arrests, and the lack of sufficient factual determinations in Tavares’s decision, the Supreme Court granted the petition for certiorari, quashed the decision, and ordered that a new decision be rendered not inconsistent with the Court’s opinion.
Mario Gianfrancesco v. A.R. Bilodeau, Inc. et al., No. 14-12 (April 17, 2015) | 14-12
The defendants, A.R. Bilodeau, Inc. (ARB) and Service Tech, Inc. (Service Tech), appealed from a Superior Court order granting preliminary injunctive relief to the plaintiff, Mario Gianfrancesco, which prevented the defendants from trespassing on the plaintiff’s property. The plaintiff and the defendants in this action were business owners with abutting properties located on Douglas Avenue in North Providence. The plaintiff owned the Geneva Diner; ARB owned property that was occupied by Service Tech, which was in the business of manufacturing and servicing water remediation and air filtration equipment. Since Service Tech began operating in this location in 1998, large delivery trucks would routinely travel on a diagonal path from Douglas Avenue, through the plaintiff’s driveway, and onto Service Tech’s premises. The plaintiff filed a complaint against the defendants in Superior Court in 2013, which included a request to quiet title as well as other claims. The plaintiff’s prayer for relief included requests for a declaratory judgment that the plaintiff was the sole and exclusive owner of his property; and injunctive relief enjoining the defendants from trespassing onto, interfering with, obstructing, or blocking the plaintiff’s business. The defendants asserted a counterclaim for easement by prescription. The defendants also moved for their own temporary restraining order, seeking to enjoin the plaintiff from blocking access to the diagonal path through the plaintiff’s driveway that the delivery trucks had been using to access Service Tech’s premises. The hearing justice granted the plaintiff’s request for preliminary injunctive relief and denied the defendants’ request for the same. The Supreme Court affirmed the order of the Superior Court granting the plaintiff’s request for preliminary injunctive relief. The Supreme Court determined that the hearing justice had not abused his discretion in finding that: (1) the plaintiff had a reasonable likelihood of success on the merits of his claims for quiet title and declaratory relief; (2) the plaintiff’s business could suffer irreparable harm if the large trucks continued to pass through the parking lot of the small diner; (3) the balance of the equities tipped in favor of the plaintiff; and (4) the issuance of a preliminary injunction would preserve the status quo.
State v. Judith Rosenbaum, Nos. 14-17, 14-18 (April 17, 2015) | 14-17, 18
The defendant, Judith Rosenbaum, appealed from a Superior Court judgment denying her request to reduce the amount of her monthly restitution obligation. The defendant had been ordered to pay $95,000 in restitution to the victim of a crime, in monthly installments of $500. She argued that she was able to pay only $237 per month, which was the amount she received monthly from a pension benefit. She further argued that, in order to pay more than $237 per month, she would have to draw from her social security income, which would contravene federal law. The Supreme Court affirmed the Superior Court’s judgment denying the defendant’s request to reduce her monthly restitution payments. The Supreme Court determined that the defendant had patently failed to meet her burden of proving that she had made sufficient efforts to comply with the restitution order. Specifically, her testimony had revealed numerous assets that could potentially be liquidated and significant expenses that could be reduced in order to direct more funds toward her restitution obligation, without requiring her to draw from her social security income. She also failed to provide documentary support of her claimed expenses and had not produced tax returns for any years after 2007, despite being instructed to do so.
Kathleen Carlson v. Town of South Kingstown et al., No. 13-280 (April 8, 2015) | 13-280
The plaintiff, Kathleen Carlson, appealed from summary judgment entered in Superior Court in favor of the defendant, the town of South Kingstown. The plaintiff’s claim was one of negligence and concerned an injury she sustained at a town-owned park while she was a spectator at her son’s little league baseball game. The plaintiff stepped into a hole alongside the park’s batting cages and suffered a broken leg. This appeal came before the Supreme Court for argument on February 4, 2015; we concluded that cause had not been shown, and we affirmed the judgment of the Superior Court. In the Superior Court, the hearing justice applied Rhode Island’s Recreational Use Statute (RUS), G.L. 1956 chapter 6 of title 32, which lowers the duty of care owed by landowners who open their land for free recreational use. The hearing justice determined that the town owed no duty to the plaintiff since she was using the park for recreational purposes at the time of her injury and no evidence showed that the town had not met this lowered duty of care. On appeal, the plaintiff argued that this was error, for three reasons, and she contended that her suit should not have been dismissed. First, the plaintiff argued that the RUS should not apply because she was not the type of user that the statute contemplates. Second, the plaintiff argued that the RUS should not apply because the town’s actions met the exception in § 32-6-5(a)(1) because the town willfully or maliciously failed to guard or warn against the dangerous condition on the field. Lastly, the plaintiff argued that the exception to the RUS set forth in § 32-6-5(a)(2) applied, saying that she was charged to use the park where she was injured because she had paid a fee to the league and taxes to the town. The Supreme Court found no error in the hearing justice’s application of the RUS and no merit to the plaintiff’s arguments that an exception should apply allowing the plaintiff to prove the town’s liability. It is our opinion that the result is precisely what the RUS and this Court’s prior holdings dictate. The plaintiff was injured in the spectator area of a public park while enjoying a recreational activity. This type of use is exactly what the RUS contemplates. Further, no evidence was presented that the town knew of the hole where the plaintiff was injured, nor was there evidence of other prior injuries on town land that resulted from a similar hazard. Lastly, the RUS exception that applies when the injured person was charged to use the land is not applicable here because neither the fee paid to the little league, nor any taxes that may have been paid to the town, affected whether or not the plaintiff was free to access the park. The plaintiff’s appeal was denied and dismissed.
HK&S Construction Holding Corp. v. Lynne S. Dible, in her official capacity as Finance Director and Purchasing Official of the Town of Middletown et al., No. 14-172 (April 7, 2015) | 14-172
The plaintiff, HK&S Construction Holding Corp. (HK&S), appealed from the Superior Court entry of summary judgment against it and in favor of the defendants, Town of Middletown, Robert J. Rafferty, and Woodard & Curran, Inc. In 2011, the town issued an invitation for bids on a drainage improvement project. Two contractors submitted bids: HK&S and C.B. Utility Company, Inc. (C.B. Utility). Having reviewed the bids, the town noted that the plaintiff’s bid was nonresponsive because it did not include the required company profile and subcontractor identification. After the town voted unanimously to award the contract to C.B. Utility, the plaintiff filed a complaint alleging wrongful denial of the contract, intentional interference with contractual relations, violations of due process and equal protection rights, and negligence. On the defendants’ motions for summary judgment, the hearing justice concluded that there was no palpable abuse of discretion in the town’s determination that the plaintiff’s bid was nonresponsive in light of the instructions given to prospective bidders. On appeal, the plaintiff argued that the hearing justice erred in making a factual determination that its bid was nonresponsive because it did not include a company profile and subcontractor identification. The Supreme Court noted that, in the bid process, the first hurdle to be crossed is the submittal of a responsive bid. The Court observed that the request for proposal required that bidders “must identify subcontractors * * * [by] includ[ing] with their bid, the subcontractors’ background information and references,” and that bidders “must provide a company profile.” Bidders were also placed on notice that “[f]ailure to completely execute and submit the required documents before the Submittal Deadline may render a bid non-responsive.” The Court acknowledged that the plaintiff’s failure to submit the documents in question was undisputed, and it concluded that there was no genuine issue of material fact that the town acted within its sound discretion in determining that the plaintiff’s bid was nonresponsive. Because the plaintiff tripped over the responsive bid hurdle, the Court declined to consider the plaintiff’s claims and affirmed the entry of summary judgment in favor of the defendants.
State v. Deaven Tucker, No. 12-361 (April 3, 2015) | 12-361
The defendant, Deaven Tucker, appealed from judgments of conviction that entered after a jury trial in Providence County Superior Court. The defendant was found guilty of ten offenses, most notably murder in the first degree of Jennifer Duarte, in violation of G.L. 1956 §§ 11-23-1 and 11-23-2. On appeal, the defendant argued that the trial justice erred when he admitted character evidence in violation of Rule 404(b) of the Rhode Island Rules of Evidence. In addition, the defendant claimed that the trial justice erred in denying his motion to pass because the prosecutor made inappropriate and inflammatory comments during his closing argument. Before trial, the state filed a motion in limine seeking the court’s guidance with respect to the admissibility of evidence relating to a murder that the defendant had orchestrated while he was in Florida in September 2006. The trial justice found that the Florida evidence was probative as to the defendant’s motive for killing Jennifer, namely, to prevent her from exposing him to prosecution for the Florida crime, and should not be kept from the jury. The trial justice subjected the Florida evidence to an analysis pursuant to Rule 403 of the Rhode Island Rules of Evidence and concluded that the potential prejudice of the evidence did not override its probative value and that the jury should be allowed to hear the evidence. At trial, three witnesses testified about the Florida events, however; none of the witnesses used the term “murder” in their testimony. Instead, the witnesses testified about a plan to “hurt” Ronald Spearin (Spearin), that Spearin was “hurt,” and that one of the witnesses heard gunshots while Spearin was being “hurt.” After each of these witnesses concluded their testimony, the trial justice provided a cautionary instruction, reminding the jury of the limited purposes for which they were allowed to consider the Florida evidence, namely the defendant’s motive to kill Jennifer. Further, Jason Ruiz (Ruiz) revealed, while being cross-examined by the defendant, that he understood the term “good lick” to mean a robbery because he had previously perpetrated such acts with the defendant. Before this testimony was elicited, Ruiz stated during voir dire that he had committed other crimes with the defendant. Despite this warning, defense counsel repeatedly questioned Ruiz about his knowledge of the term “good lick” which resulted in the revelation at issue. On review, the Supreme Court held that the trial justice did not abuse his discretion in admitting the Florida evidence because he subjected it to a thorough Rule 404(b) and Rule 403 analysis and provided numerous limiting instructions to the jury reminding them of the limited purpose for which the evidence was admitted. With respect to the “good lick” testimony, the Supreme Court held that defense counsel was on notice that Ruiz claimed that he had committed uncharged crimes with the defendant and, as a result, the trial justice did not err when he denied the defendant’s motion to pass. Finally, with respect to the prosecutor’s closing argument, the Supreme Court found that the remarks were proper in light of the evidence introduced at trial. Accordingly, the Supreme Court affirmed the judgments of conviction.
State v. Thomas H. Matthews, No. 12-299 (April 2, 2015) | 12-299
The defendant, Thomas H. Matthews, appealed from a Superior Court judgment of conviction for disorderly conduct. On appeal, the defendant contended: (1) that the trial justice erred in denying the defendant’s motion for a new trial and his motion for a judgment of acquittal; and (2) that the criminal complaint was insufficient as a matter of law to place him on notice of the charge against him. The Supreme Court held that the trial justice correctly denied the defendant’s motion for a new trial, in view of the trial justice’s careful compliance with the appropriate analysis of a motion for a new trial and the trial justice’s agreement with the jury that the defendant’s utterances fell outside the protection of the First Amendment. Specifically, the Supreme Court held that the defendant’s utterances, in the context in which they were spoken, constituted “fighting words.” The Court noted a number of factors that led it to so conclude, including: (1) the fact that there was credible testimony that the defendant’s speech was directed at the two troopers; (2) the fact that the defendant was in close physical proximity to the troopers; (3) the fact that the officers were alarmed by the defendant’s utterances; and (4) most importantly the fact that the troopers initially stopped their vehicle in order to investigate a possible altercation involving the defendant. In addition, the Court held that the trial justice correctly denied the defendant’s motion for a judgment of acquittal. Finally, the Court held that the defendant had failed to properly preserve his argument contending that the complaint was insufficient as a matter of law because the defendant did not raise this argument before the trial justice. Accordingly, the Court affirmed the trial justice’s decision in all respects and upheld the defendant’s conviction for disorderly conduct.
Thomas J. Sherman v. Yul D. Ejnes et al., No. 13-92 (April 1, 2015) | 13-92
The plaintiff, Thomas J. Sherman, petitioned the Supreme Court for a writ of certiorari seeking review of a Superior Court order that severed his claim for exemplary damages and stayed discovery on that issue pending a determination on liability. The Court granted the petition, directing the parties to address whether the order of the Superior Court should be summarily quashed as a result of the hearing justice’s failure to comply with the procedures set forth in Palmisano v. Toth, 624 A.2d 314, 320-21 (R.I. 1993). The plaintiff filed suit against the defendants alleging that they willfully, knowingly, intentionally, recklessly, and negligently failed to protect the confidentiality of his HIV test results. As a result, the plaintiff sought to recover compensatory damages as well as exemplary damages pursuant to G.L. 1956 § 5-37.3-9. During the course of pretrial discovery, the plaintiff requested that the defendant doctor disclose personal financial information. The defendant objected, and eventually moved to strike the plaintiff’s claim for exemplary damages relying upon Palmisano. Significantly, the parties requested that the Superior Court conduct an evidentiary hearing to determine the viability of the plaintiff’s exemplary-damages claim. Notwithstanding the parties’ request, the hearing justice declined to schedule a hearing and declared that it was his practice to sever the exemplary-damages claim until a determination on liability had been made. The Supreme Court held that the hearing justice erred in failing to conduct an evidentiary hearing when confronted with the defendant’s motion to strike the plaintiff’s exemplary-damages claim. The Supreme Court explained that, because the plaintiff sought the disclosure of information related to the personal finances of the defendant, an evidentiary hearing should have been conducted, at which the parties would be afforded the opportunity to present evidence, examine witnesses, and to otherwise determine the viability of the plaintiff’s exemplary-damages claim. Accordingly, the Supreme Court quashed the order of the Superior Court and remanded the case with its decision endorsed thereon.
Joyce Duffy et al. v. Estate of Bartolomie Scire, Nos. 11-119, 11-156 (April 1, 2015) | 11-119, 11-156
The matters at issue in this case involved a petition filed by Joyce Duffy and Donna O’Reilly (plaintiffs) for the appointment of a guardian over their father, Bartolomie Scire. After a judge of the Warwick Probate Court denied the petition, the plaintiffs appealed to the Kent County Superior Court, where their complaint for review of the probate decision was dismissed due to the fact that they had failed to timely file a copy of the probate record as required under G.L. 1956 § 33-23-1(a). The plaintiffs subsequently moved to allow their appeal to proceed pursuant to G.L. 1956 § 9-21-6, which statute would have permitted their appeal if their failure to file the record on time was due to excusable neglect. The hearing justice denied their § 9-21-6 motion. On appeal, plaintiffs argued that the hearing justice erred in denying their motion because their failure to file the probate record was due to an alleged delay in the Probate Court Clerk’s Office. The Supreme Court held that the probate appeal could not proceed pursuant to § 33-23-1(a), due to the fact that filing a copy of the probate record in a timely fashion was a jurisdictional requirement. However, the Supreme Court held that the appeal should have been permitted to proceed under § 9-21-6; the Court stated that there was excusable neglect present in the case. Consequently, the Court vacated the decision of the Superior Court and remanded the case to that tribunal for a hearing on the merits.
(March 30, 2015) | 13-103, 13-104
Albert A. Faella et al. v. Joseph Chiodo, in his capacity as Finance Director for the Town of Johnston et al.; Alan Ross v. Town of Johnston et al., Nos. 13-103, 13-104 The defendant, Town of Johnston (Johnston or town) appealed the grant of summary judgment in favor of the plaintiffs, who are all former Johnston police officers who retired on injury disability. The Superior Court had found, based on the doctrine of equitable estoppel, that the plaintiffs were entitled to distributions from accounts maintained by ING Life Insurance and Annuity Company in addition to any pension payments they were to receive from the town. The Supreme Court held that equitable estoppel is an extreme remedy, especially against a municipality, that is dependent on the facts and circumstances of each case. Accordingly, the Supreme Court reversed the grant of summary judgment in light of the various factual issues.
Gerald Lopes v. State of Rhode Island, No. 11-380 (March 26, 2015) | 11-380
This appeal came before the Supreme Court pursuant to an order directing the parties to appear and show cause why the issues raised in this appeal should not summarily be decided. Gerald Lopes (Lopes) seeks review of the denial of his application for postconviction relief. Lopes entered a plea of nolo contendere in two separate cases to the charges of burglary, breaking and entering, and receiving stolen goods. Lopes later applied for postconviction relief in the Superior Court, alleging myriad grounds for relief, including: (1) constitutional violations of the Fifth, Sixth, and Fourteenth Amendments to the United States Constitution; (2) due process violations; (3) ineffective assistance of trial counsel; (4) prosecutorial misconduct; and (5) new evidence. The Supreme Court held that the trial justice had not erred in finding that Lopes had knowingly and voluntarily pled to the charges. The Court also concluded that Lopes had failed to satisfy his burden of proof with regard to his allegations of ineffective assistance of counsel. Accordingly, the Court affirmed the judgment of the Superior Court.
David F. Miller et al. v. Metropolitan Property and Casualty Insurance Co. et al., Nos. 13-60, 13-61, 13-62 (March 20, 2015) | 13-60, 13-61, 13-62
The Supreme Court’s opinion addressed three appeals arising from the complaint filed by the plaintiff, David F. Miller, against the defendants, Amica Mutual Insurance Company, Amica Property and Casualty Insurance Company (collectively Amica), and Metropolitan Property and Casualty Insurance Company (Metropolitan). Beginning in 2001, the plaintiff fell under the suspicion of the Rhode Island State Police (State Police), who, with the help of the defendants, conducted an investigation into insurance claims at the plaintiff’s Cumberland auto body shop. The plaintiff was later arrested and charged by the Rhode Island Attorney General (Attorney General), but those charges ultimately were dismissed upon certain conditions. Those conditions were: (1) that the plaintiff relinquish or transfer his auto-body license, (2) that the plaintiff pay restitution to the defendants, and (3) that the plaintiff execute a general-liability release in favor of the Attorney General, the State Police, and the defendants. Fifteen months later, the plaintiff filed his complaint, alleging eight counts, including tortious interference with contracts, malicious prosecution, and abuse of process. Of the eight counts, all except the abuse-of-process claim were dismissed prior to trial on motions for summary judgment granted in favor of the defendants. After a jury trial, where the plaintiff secured verdicts in his favor, the trial justice granted Amica’s motion for judgment as a matter of law, but denied the same motion from Metropolitan. The plaintiff appealed the former decision, and the prior judgments in Amica’s favor, and Metropolitan appealed the latter. The plaintiff then cross-appealed the pretrial rulings in Metropolitan’s favor, resulting in three separate appeals. On review, the Supreme Court found that the release that the plaintiff signed to end the criminal prosecution explicitly barred the plaintiff from pursuing civil claims against the defendants. The plaintiff received consideration for the release, in the form of the termination of the prosecution, he is an experienced businessman who would have been aware of the consequences of signing such a document, and he was advised by counsel throughout the process. The plaintiff argues that despite these facts the release should not be valid because he signed the release under duress. However, the plaintiff could not produce sufficient evidence, at the summary judgment stage or at trial, to show that the defendants’ conduct rose to the level of legal duress because the defendants did not commit an unlawful act and the plaintiff had more than one legitimate choice when he contemplated signing the release. Applying settled law, the release was found to be valid and should have been the basis for the trial justice to grant judgment to the defendants on all counts of the complaint. Accordingly, the Supreme Court affirmed the pretrial grants of summary judgment for Amica and Metropolitan. With respect to the abuse of process claim that went to trial, the Supreme Court affirmed the trial justice’s grant of judgment as a matter of law in favor of Amica, and reversed the trial justice’s decision and granted judgment as a matter of law for Metropolitan. Justice Goldberg did not participate.
State v. Joseph Armour, No. 13-110 (March 17, 2015) | 13-110
This case came before the Rhode Island Supreme Court on February 3, 2015, on appeal by the defendant, Joseph Armour (defendant), from a Superior Court judgment of conviction following a jury verdict of guilty of one count of second-degree child molestation. The defendant contended that the trial justice erred in: (1) denying his motion to suppress an incriminating confession he gave to the police; (2) permitting Dr. Amy Goldberg to testify regarding the explanation of a normal examination over defense counsel’s objection; and (3) denying the defendant’s motion for judgment of acquittal. After thorough examination of the record, the Supreme Court determined that, in light of the trial justice’s findings of historical fact and credibility determinations which are viewed with deference, the trial justice did nor err in concluding that the defendant’s confession was given voluntarily. Next, the Court concluded that the defendant had not properly preserved his objection to Dr. Goldberg’s testimony. Lastly, the Court determined that there was more than sufficient evidence to support the defendant’s conviction and denied his motion for judgment of acquittal. Accordingly, the Court affirmed the Superior Court judgment.
Jennifer O’Connor v. Newport Hospital et al., No. 12-87 (March 17, 2015) | 12-87
The plaintiff, Jennifer O’Connor, appealed from a verdict returned in favor of all of the defendants in this medical malpractice action. O’Connor had filed suit against an emergency- room physician, the physician’s employer, and the hospital where the allegedly negligent medical treatment had been provided, claiming that the defendants were liable for the permanent injuries she sustained after the defendants had allegedly failed to provide the correct diagnosis and treatment while she was in the emergency room at Newport Hospital. On appeal, the plaintiff claimed that she was entitled to a new trial because the trial justice erred by admitting three documents into evidence during the voir dire of the plaintiff’s standard-of-care expert, and that this error, exacerbated by biased and incorrect language on the jury verdict form, was sufficiently prejudicial to warrant a new trial. The documents at issue included printouts from two web pages and an email communication, all of which purported to show that the plaintiff’s expert witness, a Canadian physician, was not eligible to become a board-certified emergency-medicine physician in the United States. The authentication of each document was a matter of first impression in Rhode Island. The Supreme Court held that the brief testimony of one witness (the Canadian medical expert) who was clearly unfamiliar with all three documents was insufficient to support the authenticity of the documents. The Supreme Court also held that each document was inadmissible as hearsay. The trial justice, therefore, abused his discretion by admitting the three documents into evidence. The plaintiff had also objected to the wording of the first question on the jury verdict form, which asked whether the plaintiff had proven that the defendant-physician had breached the standard of care “for an emergency medicine physician practicing in the United States.” The plaintiff contended that the wording was biased and incorrect, and also reinforced the core of the defendants’ criticism of the Canadian expert witness, and, ultimately, the import of the three improperly admitted documents. The Supreme Court concluded that, while the language might pass muster in another medical malpractice case, when viewed in light of the circumstances of this case, the jury verdict question highlighted information contained in the three documents and contributed to the prejudicial effect of the erroneously admitted documents. The phrase “practicing in the United States” drew attention to the fact that the Canadian medical expert witness was not board-certified in the United States, and the Court also noted that, while the witness had already testified that he was not board-certified in the United States, the three documents were available to the jury during its deliberations because each was admitted as a full exhibit. Ultimately, the Supreme Court held that there was sufficient prejudice to warrant a new trial because the improperly admitted documents could reasonably have influenced the jury’s determination of the central issue in this case and the jury could have been misled into lending more weight to the expert witness’s nationality than appropriate, resulting in prejudice to the plaintiff. Accordingly, the Supreme Court vacated the judgment and remanded the case for a new trial.
Atwood Health Properties, LLC v. Calson Construction Company v. Gem Plumbing & Heating Co., Inc., Nos. 13-306, 14-27 (March 17, 2015) | 13-306, 14-27
The defendant, Calson Construction Company (Calson), and the third-party defendant, Gem Plumbing & Heating Co., Inc. (GEM), (collectively, defendants) appeal a Superior Court order confirming an arbitration award in favor of the plaintiff, Atwood Health Properties, LLC (Atwood or plaintiff). On appeal, Calson argued that the trial justice improperly confirmed an arbitration award; however, because Calson failed to object to Atwood’s request for confirmation and, in fact, requested that the Superior Court confirm the arbitration award, the Rhode Island Supreme Court deemed Calson’s appeal waived. Turning to GEM’s appeal, GEM argued that: (1) the arbitrator manifestly disregarded the contract and applicable law when he failed to make a finding of negligence before determining that GEM was in breach—a finding that GEM avows was required according to the indemnity clause in the contract with Calson; (2) the arbitrator’s reliance on the indemnification provision was in violation of G.L. 1956 § 6-34-1; (3) Atwood’s claims are time barred; and (4) the calculation of damages was irrational. After a thorough review of the record, the Supreme Court was not persuaded by GEM’s contentions and affirmed the trial justice’s determination.
Retirement Board of the Employees’ Retirement System of the City of Providence v. Frank E. Corrente and Angel Taveras, in his capacity as the Mayor of the City of Providence (intervenor)and the City of Providence (intervenor), Nos. 12-110, 12-111, 12-112 | 12-110, 111, 112
These appeals arose from a decision of the Retirement Board of the Employees’ Retirement System of the City of Providence (board) to reduce the pension of former city employee Frank E. Corrente. Corrente had been convicted on six criminal charges stemming from his employment as the Director of Administration for former mayor Vincent A. Cianci, Jr. Pursuant to the “Honorable Service Ordinance” (HSO), Chapter 17, Article VI, § 17-189.1 of the City of Providence Code of Ordinances (as enacted in 1999), the board had voted to reduce Corrente’s pension benefits and then filed a miscellaneous petition in the Superior Court requesting that the court confirm its decision. The mayor and the city (intervenors) were allowed to intervene in the matter, and a Superior Court justice confirmed the board’s decision to reduce Corrente’s pension. The intervenors appealed the order of the Superior Court confirming the board’s decision, and the board cross-appealed the trial justice’s decision granting the intervenors’ motion to intervene. On appeal, the Supreme Court first issued an order directing the parties to file supplemental briefs addressing the threshold issue of whether the Superior Court was properly vested with subject-matter jurisdiction over the case. After the Supreme Court issued this order, the General Assembly enacted a new statute, G.L. 1956 § 36-10.1-5, which granted subject-matter jurisdiction to the Superior Court over cases brought pursuant to the HSO. The Supreme Court held that, because the case was filed pursuant to the HSO and was adjudicated in the Superior Court prior to the enactment of § 36-10.1-5, the Superior Court lacked subject-matter jurisdiction. The Supreme Court held that the final judgment of the Superior Court was therefore void. The Supreme Court further held, however, that the Superior Court was now vested with jurisdiction over the case. Accordingly, the Supreme Court remanded the matter to the Superior Court. The Superior Court was directed to use its discretion to either conduct further proceedings based upon the record before the court, or, in its discretion, to re-enter its previous judgment.
State v. Michael Tully, a.k.a. Michael Vanover, No. 13-282 (March 9, 2015) | 13-282
The defendant, Michael Tully, appealed from a conviction of first-degree felony murder and conspiracy to commit robbery, as well as from the denial of his motion for a new trial. The charges resulted from an attempted robbery that resulted in the death of one Ralph Joseph. On appeal, the defendant first argued that the trial justice erred in denying his motion to pass the case. This motion had been made during trial, after the state’s main witness unexpectedly testified that she had seen and recognized the defendant’s face during the commission of the crime. The Supreme Court affirmed the trial justice’s denial of the defendant’s motion. The Supreme Court held that the witness’s inconsistent testimony did not amount to a discovery violation and merely provided defense counsel with fodder for impeachment upon cross-examination. Next, the defendant argued that the trial justice erred in denying his motion for a new trial. The defendant asserted that the verdicts in the case were inconsistent and that there was a lack of evidence to support a conviction for the charge of conspiracy to commit robbery. The Supreme Court affirmed the trial justice’s denial of the defendant’s motion. The Supreme Court noted that verdicts need not be logically consistent so long as they are legally consistent and held that the verdicts in this case were indeed legally consistent. Additionally, the Court concluded that the trial justice was not clearly wrong in agreeing with the jury’s finding that the defendant was guilty of conspiracy.
State v. Wilson Rodriguez, No. 13-294 (March 9, 2015) | 13-294
This appeal came before the Supreme Court pursuant to an order directing the parties to appear and show cause why the issues raised in this appeal should not summarily be decided. The defendant, Wilson Rodriguez (defendant), appealed from a judgment of conviction after a jury verdict found him guilty of one count of delivery of a controlled substance, to wit cocaine. In support of his appeal, the defendant argued that the trial justice erred in: (1) his denial of the defendant’s motion in limine to bar the testimony of detectives who conducted surveillance of the defendant; (2) his charge to the jury; (3) his failure to include certain portions of cross-examination testimony of a detective during a read back to the jury; (4) his denial of the defendant’s motion for judgment of acquittal; and (5) his denial of the defendant’s motion for a new trial. The Supreme Court determined that cause had not been shown and affirmed the judgment of the Superior Court.
Renewable Resources, Inc. v. Town of Westerly, No. 13-101 (March 4, 2015) | 13-101
The plaintiff, Renewable Resources, Inc., appealed from a Superior Court order vacating a preliminary injunction halting demolition of the Potter Hill Mill (the mill), as well as a subsequent judgment dismissing the remaining counts of the plaintiff’s amended complaint against the defendant the Town of Westerly (the town). On appeal, the plaintiff argued that the hearing justice abused his discretion in failing to find a change in circumstances warranting the mill’s demolition. The Supreme Court recounted that the plaintiff’s breach of the 2006 memorandum of agreement (MOA), which outlined the plaintiff’s duties in rehabilitating the mill, served as the impetus for the hearing justice’s decision to vacate the preliminary injunction. The Court acknowledged that the preliminary injunction functioned as an enforcement mechanism for the MOA, given that it was supplemented by orders to commence the reconstruction and repair of the mill’s buildings. Further, the Court noted that, between the granting of the preliminary injunction and the filing of the emergency motion for relief, the town twice sought to hold the plaintiff in contempt. The Court reasoned that, because this noncompliance resulted in the mill’s advanced state of deterioration, the plaintiff’s breach was sufficient to constitute a change in circumstances. As a result, the Court held that the hearing justice did not abuse his discretion in granting the town’s emergency motion for relief. Finally, the Court deemed any argument relating to the hearing justice’s dismissal of counts 1 and 2 of the plaintiff’s amended complaint to have been waived.
Narragansett Indian Tribe v. State of Rhode Island and UTGR, Inc. d/b/a Twin River and Newport Grand, LLC (Intervenors), No. 12-322 (March 4, 2015) | 12-322
The plaintiff, Narragansett Indian Tribe (Tribe), appealed the entry of partial summary judgment against its challenge to the facial constitutionality of the 2011 Casino Act G.L. 1956 chapter 61.2 of title 42 (Casino Act). The Tribe argued that the Casino Act violated article 6, section 15 of the Rhode Island Constitution, which provides that “[a]ll lotteries shall be prohibited in the state except lotteries operated by the state * * *.” Additionally, the Tribe asserted that the Casino Act was unconstitutionally vague and in violation of the non-delegation doctrine embodied in sections 1 and 2 of article 6 of the Rhode Island Constitution. The Supreme Court held that the Casino Act was not facially unconstitutional because it vested the state with “full operational control” and the “authority to make all decisions about all aspects of the functioning of the business enterprise * * *.” Additionally, the Court noted that the Casino Act contains a clause which provides that the state shall “[h]old all other powers necessary and proper to fully effectively execute and administer the provisions of” the Casino Act. The Supreme Court declined to take into consideration subsequent legislation and materials produced by the state in connection with the Casino Act that were not addressed by the hearing justice, leaving these matters to be addressed in the context of the Tribe’s as-applied challenge, which remains pending in the Superior Court.
In the Matter of Keven A. McKenna, No. 14-148 (February 27, 2015) | 14-148
This attorney disciplinary matter came before the Supreme Court pursuant to a recommendation of the Disciplinary Board of the Rhode Island Supreme Court (board) that the respondent, Keven A. McKenna, be suspended from the practice of law for a period of one year. This recommendation stemmed from McKenna’s misconduct in: engaging in the unauthorized practice of law as a limited liability entity; failing to disclose his income and misrepresenting his interest in a receivable to the United States Bankruptcy Court for the District of Rhode Island; engaging in conduct that amounted to a lack of candor, dishonesty, and misrepresentation to the bankruptcy trustee; failing to keep and provide records that were subpoenaed by Assistant Disciplinary Counsel; and engaging in conduct during proceedings in the Workers’ Compensation Court and Bankruptcy Court that demonstrated a lack of candor and an attempt to disrupt these tribunals. A three-member panel of the board conducted eight hearings on this matter and found that McKenna had violated Article V, Rules 1.19, 3.3, 3.5, 7.1, 7.5, and 8.4 of the Supreme Court Rules of Professional Conduct. The board adopted the findings of the panel and submitted its recommendation to the Supreme Court. McKenna then filed two motions to dismiss, a motion to stay the proceedings pursuant to G.L. 1956 § 9-33-2, and a motion to recuse the justices of the Supreme Court. Throughout the proceedings, McKenna challenged the authority of the Supreme Court to regulate attorneys, as well as its and the board’s jurisdiction over matters of attorney discipline, and he alleged that the proceedings before the board and the Supreme Court violated his procedural due process rights. The Supreme Court denied McKenna’s motions and adopted the recommendation of the board. The Court held that it had jurisdiction over attorney disciplinary matters and that McKenna’s due process rights had not been compromised by the disciplinary process. The Supreme Court further held that McKenna had failed to establish any facts warranting recusal, and that § 9-33-2 was inapplicable to attorney disciplinary proceedings. The Supreme Court agreed with the board’s findings of misconduct and ordered that McKenna be suspended from the practice of law for a period of one year.
Joseph Laplante et al. v. Rhode Island Hospital et al., No. 12-257 (February 25, 2015) | 12-257
The plaintiff, Joseph Laplante, appealed pro se from the Providence County Superior Court’s grant of summary judgment in favor of the defendants, Rhode Island Hospital, Lifespan, Inc., Frantz J. Gibbs, M.D., and Michael P. Bradley, M.D. On appeal, the plaintiff argued that the hearing justice in this case: (1) overlooked genuine disputes as to material facts that would preclude summary judgment; (2) failed to apply the doctrine of res ipsa loquitur; and (3) erred in granting summary judgment in light of what the plaintiff characterized as the egregious conduct of his attorney in the Superior Court. The Supreme Court held that, because the plaintiff was barred from presenting expert testimony due to his conduct during the discovery phase of litigation, he would not be able to demonstrate any genuine dispute as to a material fact considering the complexity of his medical malpractice claim. In addition, the Supreme Court held that the hearing justice correctly found that the doctrine of res ipsa loquitur did not apply to the plaintiff’s claims, primarily because the plaintiff was barred from presenting expert testimony and the defendants’ alleged negligence was not so obvious as to be evident to a layperson. Finally, the Supreme Court held that the plaintiff waived any claim stemming from alleged attorney misconduct in light of his failure to raise it before the hearing justice. Consequently, the Supreme Court affirmed the hearing justice’s grant of the defendants’ motion for summary judgment.
Ferris Avenue Realty, LLC v. Huhtamaki, Inc., et al., No. 13-233 (February 25, 2015) | 13-344
This case arose from the refusal of the defendant, Huhtamaki, Inc. (Huhtamaki), to indemnify the plaintiff, Ferris Avenue Realty, LLC (Ferris), after Ferris incurred costs related to the cleanup of hazardous substances. After a thirteen-day trial, a jury found in favor of Ferris. On appeal, Huhtamaki argued that the trial justice erred in: (1) finding that Ferris provided sufficient notice to Huhtamaki in accordance with the parties’ Indemnity Agreement; (2) admitting certain testimony from an expert witness; (3) admitting allegedly spoliated evidence; (4) instructing the jury; and (5) permitting Ferris to rely upon what Huhtamaki contended was “a pyramid of inferences” as Ferris sought to prove its case. The Supreme Court held that: (1) Huhtamaki received actual notice; (2) the trial justice properly exercised his discretion in permitting Ferris’s expert witness to testify with respect to the presence of hazardous substances on the property in question; (3) the trial justice did not commit reversible error in admitting the allegedly spoliated evidence; (4) Huhtamaki’s claims of error with respect to the charge to the jury were either unfounded or unpreserved; and (5) Huhtamaki’s argument that Ferris relied upon an impermissible “pyramid of inferences” was meritless. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
Bruce Brayman Builders, Inc. v. James M. Lamphere, in his capacity as Town Planner for the Town of Hopkinton, No. 13-53 (February 13, 2015) | 13-53
This case arose from a dispute over a preliminary plan application for a minor subdivision submitted by the plaintiff, Bruce Brayman Builders, Inc. (Brayman). The defendant, James M. Lamphere, in his capacity as Town Planner for the Town of Hopkinton, refused to certify Brayman’s application as complete due to unpaid personal property taxes; that refusal was premised upon the defendant’s interpretation of the pertinent regulations as requiring that both the personal property taxes and real property taxes of an applicant must be paid up. Brayman, contending that said requirement applied only to real property taxes, sought declaratory relief to that effect from the Superior Court. The parties eventually cross-moved for summary judgment with respect to the proper interpretation of the term “property taxes.” The trial justice denied both motions and then sua sponte denied Brayman’s request for declaratory relief due to what the trial justice described as Brayman’s failure to have exhausted its administrative remedies. The Supreme Court held that the trial justice abused his discretion in sua sponte relying upon the administrative exhaustion doctrine to deny Brayman declaratory relief where neither party had briefed or argued the issue of administrative exhaustion at the summary judgment stage. Accordingly, the Court vacated the judgment of the Superior Court.
Dawn L. Huntley v. State of Rhode Island et al., No. 13-253 (February 12, 2015) | 13-253
The plaintiff, Dawn L. Huntley, and her attorney, Nicholas S. Gelfuso, jointly appealed from a final judgment entered in favor of the defendants. On appeal, the appellants contended that the hearing justice erred in: (1) vacating the entry of default against the defendant Alan Goulart; (2) denying Ms. Huntley’s applications for entry of default against the defendants Gerald Coyne and Patrick Lynch; and (3) imposing a monetary sanction upon Attorney Gelfuso pursuant to Rule 11 of the Superior Court Rules of Civil Procedure. The Court first determined that the hearing justice acted correctly in removing the entry of default against Mr. Goulart and in denying the applications for default against Mr. Coyne and Mr. Lynch; the Court predicated that determination on the fact that its April 2013 decision barring Ms. Huntley’s claims on the basis of res judicata applied to the above defendants. Additionally, the Court discerned no abuse of discretion in the monetary sanction imposed by the Superior Court upon Attorney Gelfuso in light of the hearing justice’s careful review of the record and Attorney Gelfuso’s rather egregious misrepresentations.
State v. Ana M. Cruz, No. 13-281 (February 11, 2015) | 13-281
The defendant, Ana M. Cuz, appealed from a Superior Court judgment of conviction, having been found guilty on two counts: (1) resisting arrest in violation of G.L. 1956 § 12-7-10; and (2) disorderly conduct in violation of G.L. 1956 § 11-45-1. The defendant contended that her Sixth Amendment right to counsel, guaranteed by the United States and Rhode Island Constitutions, was violated when the trial justice allowed her to represent herself at trial without first determining whether she had made a knowing and intelligent waiver of her right to counsel. Midway through jury selection, the defendant informed the trial justice that she wanted to waive her right to counsel and proceed pro se at trial. The trial justice engaged in a detailed colloquy with the defendant to make her aware of the potential risks of self-representation. Notwithstanding this colloquy, the defendant’s appellate argument asserted that her waiver of counsel was constitutionally deficient because it was not made knowingly and intelligently. After careful consideration, the Supreme Court concluded that the record established the defendant’s voluntary, knowing, and intelligent waiver of counsel. Accordingly, the Court affirmed the judgment of the Superior Court.
Heritage Healthcare Services, Inc., et al. v. The Beacon Mutual Insurance Co., et al., No. 13-102 (February 6, 2015) | 13-102
The plaintiffs, a certified class of approximately 14,000 policyholders of The Beacon Mutual Insurance Company (Beacon), appealed a Superior Court judgment that dismissed their complaint. The plaintiffs alleged that from September 2001 to March 2006, Beacon engaged in a systematic scheme to divert over $101 million to a small percentage of its policyholders rather than distributing it equitably to all its policyholders. The plaintiffs further alleged that Beacon ceased formally declaring and distributing annual dividends from 2002 until 2004 and instead charged inequitable and unauthorized lower premiums, referred to as consent-to-rate discounts, to certain of its largest policyholders, instead of filing lower rates for all its policyholders. As a result, the plaintiffs concluded that because of the consent-to-rate discounts, they were denied money that should have been equitably distributed to all policyholders as dividends. On appeal, the plaintiffs argued that the hearing justice erred when he held that their claims were derivative in nature and when he dismissed their complaint for not satisfying the procedural requirements associated with a derivative action. The plaintiffs argued that their claims were direct, because governing law entitled them to an equitable distribution of the excess surplus of the company and because they suffered disproportionate harm as compared to other policyholders. Further, the plaintiffs argued that Beacon’s failure to formally declare a dividend does not transform the nature of their claims from direct to derivative. Finally, the plaintiffs insisted that the hearing justice erred in holding that Beacon was authorized to distribute consent-to-rate discounts to its policyholders. The Supreme Court determined that governing law did not entitle the plaintiffs to an equitable distribution of Beacon’s excess surplus because the complaint alleged that Beacon diverted $101 million as consent-to-rate discounts. Therefore, Beacon never collected the $101 million and that money never became excess surplus that could have been equitably distributed. Next, the Supreme Court determined that, even if the $101 million had been collected, the plaintiffs would not have necessarily been entitled to an equitable distribution because Beacon’s authority to issue dividends was discretionary. Finally, the Supreme Court found that, assuming Beacon was not authorized to issue consent-to-rate discounts would not transform the plaintiffs’ claims into direct claims. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
Kristopher Plante et al. v. Daniel Stack et al. v. Bella Restaurant, No. 2012-319 (February 6, 2015) | 12-319
The defendants, Daniel Stack and the Disabled American Veterans Department of Massachusetts, Inc., petitioned for a writ of certiorari seeking review of three Superior Court rulings in the underlying negligence action. On appeal, the defendants requested that the Court reverse the hearing justice’s rulings: (1) denying the defendants’ motion to compel additional testimony from the Plante family; (2) granting the plaintiffs’ motion for a protective order limiting the defendants’ planned neuropsychological examination of the plaintiff; and (3) revoking defense counsel’s pro hac vice admission. The petition for certiorari was denied in part and granted in part. The Supreme Court affirmed the denial of the defendants’ motion to compel additional testimony from the Plante family as well as the portion of the protective order allowing for one non-attorney representative to be present during the testing phase of the neuropsychological examination, and it quashed the writ of certiorari as to those issues. The Court granted certiorari, however, as to the rulings that no history was allowed be taken by the defendants’ neuropsychologist and that the plaintiffs’ counsel was allowed to be present during the testing phase of the examination. Those portions of the protective order were quashed. Finally, the Court granted certiorari on the revocation of defense counsel’s pro hac vice admission and quashed the ruling as to that issue.
Mary Lou Dauray v. Gabrielle D. Mee (a/k/a Gabrielle Malvina Mee);Mary Lou Dauray, as heir-at-law of Gabrielle D. Mee, and on behalf of the Estate of Gabrielle D. Mee v. Legion of Christ et al.; Mary Lou Dauray, as heir-at-law of | 13-135, 136, 137
These three separate appeals are brought by the plaintiff, Mary Lou Dauray (Dauray), challenging the Superior Court’s grant of summary judgment determining that she did not have standing to maintain the actions. The three appeals brought by Dauray are: (1) an appeal of a probate court order admitting the will of Dauray’s aunt, Gabrielle D. Mee (Gabrielle), claiming that the will was executed through undue influence, fraud, and mistake in the inducement; (2) an appeal from a suit claiming that Gabrielle was unduly influenced and fraudulently induced into giving approximately $60 million in lifetime gifts to the Legion of Christ North America, Inc. (Legion of Christ); and (3) an appeal from an action alleging that Bank of America, N.A., as successor-in-interest by merger or otherwise to Fleet National Bank, breached its fiduciary duties as trustee of multiple trusts set up by Gabrielle and her husband. In these three appeals, Dauray argued that the trial justice was incorrect in his determination that Dauray was not a person legally interested in the estate and, thus, did not have standing either under the common law or pursuant to G.L. 1956 § 33-18-17. Dauray argued that the mere fact that she was an heir-at-law of Gabrielle meant that she had standing. Furthermore, Dauray asserted that the trial justice abused his discretion when he conditioned the filing of Dauray’s amendment to her reasons for appeal of the probate court decision upon the payment of attorneys’ fees associated with taking the prior deposition of Dauray pursuant to G.L. 1956 § 33-23-1(a)(2). The Supreme Court affirmed the trial justice with respect to his determination that Dauray lacked standing to challenge the will of Gabrielle. The Court determined that, because there was a valid and enforceable residuary clause, even if partial intestacy did result, the residuary beneficiaries would be eligible to take; and, thus, Dauray had no possibility of inheriting from the will. Because of this determination, the Court concluded that Dauray could not be a person legally interested in the estate of Gabrielle; and therefore, she did not have standing pursuant to § 33-18-17. However, the Court determined that the trial justice abused his discretion in awarding attorneys’ fees as a condition of amending Dauray’s reasons for appeal of the probate court decision because the imposition of retrospective attorneys’ fees did not comport with what was right and equitable under the circumstances. Accordingly, the Supreme Court affirmed in part and vacated in part the judgment of the Superior Court. Justice Flaherty did not participate.
State v. Victor Arciliares, No. 13-124 (January 26, 2015) | 13-124
The defendant, Victor Arciliares, appealed from a judgment of conviction entered after a jury trial in Providence County Superior Court. The defendant was found guilty of five offenses, most notably murder in the first degree, in violation of G.L. 1956 § 11-23-1. The defendant contended that the trial justice erred when he curtailed the extent to which the defendant was allowed to cross-examine a key prosecution witness. The defendant claimed that the exclusion of the proffered evidence was reversible error and merits a new trial. The defendant was on trial for murder and other violent offenses that arose out of his alleged involvement with the shooting death of Alfredo Barros on October 30, 2010, in Pawtucket. The gun that fired the fatal bullets was never found. Similarly, the car that eyewitnesses said they saw at the scene of the shooting was never found. The police officers who investigated the case had few leads for months after the shooting, and little information was released to the public. The break in the case came when an informant told an investigator at the Adult Correctional Institutions (ACI) that he had information about the murder. This informant implicated the defendant by claiming that the defendant had divulged to him details of the murder in the form of a confession. The state’s case consisted mainly of this one key witness. The state argued that the defendant would only have been privy to the details of the murder because he was in fact guilty of the crime. The defendant claimed that he knew of the details because he was questioned by a Pawtucket Police detective in the course of the investigation. When this detective was on the stand, the defendant was prevented from asking him what details of the murder he told to the defendant at their meeting. The judge sustained the state’s objection to the testimony on the grounds that the testimony violated the rule set forth in State v. Harnois, 638 A.2d 532, 535-36 (R.I. 1994), which would not allow the defendant to ask witnesses about statements the defendant himself had made. On review, the Supreme Court found that the testimony the defendant desired to elicit from the detective was not barred by Harnois, because the defendant sought for the detective to recount his own statements, as opposed to the defendant’s statements. The Supreme Court held that the desired testimony was relevant because it might have shown that the defendant was told many of the details about the murder without being involved himself. This testimony would have allowed the defendant to argue that the informant heard these details in an innocent conversation with the defendant and the informant then fabricated his testimony to extract favorable treatment from the state. Accordingly, the restriction of cross-examination was an error by the trial justice because it undercut the defendant’s strongest defense. Consequently, the Supreme Court vacated the defendant’s convictions. The case will be remanded to the Superior Court for a new trial.
Carol A. Maccarone v. Raymond J. Maccarone, Jr., Nos. 13-369, 13-370 (January 26, 2015) | 13-369, 13-370
The defendant, Raymond J. Maccarone, Jr., appealed from a Family Court judgment entered in favor of the plaintiff, Carol A. Maccarone, enforcing a property settlement agreement that was incorporated but not merged into the parties’ final judgment of divorce. The plaintiff cross-appealed the denial of her motion to dismiss the defendant’s appeal. The defendant, who did not retire upon reaching the age of eligibility, argued that the Family Court justice should not have awarded the plaintiff her share of his pension benefits, plus interest, because the property settlement agreement clearly set the valuation date as the date of his retirement. The Supreme Court found that the property settlement agreement was ambiguous, reasoning that it was open to more than one reasonable interpretation and that, as such, the Family Court justice properly resolved the ambiguity based on the principles of equitable distribution. The Court also held that interest was properly awarded, as Raymond’s failure to place $25,000 in an escrow account constituted a breach of contract, thus triggering the application of interest under G.L. 1956 § 9-21-10. Finally, the Court remanded the issue of attorney’s fees to the Family Court, and directed it to address the basis for such an award and the calculation thereof. In light of the affirmance of the Family Court judgment in the plaintiff’s favor, the Court concluded that her cross-appeal was moot and elected not to decide it.
Rafael Genao v. Litton Loan Servicing, L.P. et al., Nos. 13-262, 12-127 (January 16, 2015) | 13-262-12-127
The plaintiff, Rafael Genao, appealed from the Superior Court’s entry of summary judgment against him and in favor of the defendants Litton Loan Servicing, L.P. (Litton) and Deutsche Bank, National Trust Company (Deutsche Bank). In a related matter, the Supreme Court granted Mortgage Electronic Registration Systems, Inc.’s (MERS) petition for a writ of certiorari, which sought review of a Superior Court order denying its motion for a protective order. The plaintiff had executed a note and mortgage on his commercial real property with Equity One Mortgage Company (Equity One) as the lender and MERS as the named mortgagee. When the plaintiff failed to make timely payments, foreclosure proceedings were initiated. The plaintiff filed an action in the Superior Court seeking a declaratory judgment, injunctive relief, an order quieting title, and compensatory damages, and sought to depose a MERS designee. Before this Court, MERS contended that the hearing justice should have granted its motion for a protective order quashing the deposition because the plaintiff had no standing to challenge the validity of an assignment to which he was neither a party nor a third party beneficiary. In the wake of adopting the rationale of the United States Court of Appeals for the First Circuit in Wilson v. HSBC Mortgage Services, Inc., 744 F.3d 1 (1st Cir. 2014), the Court rejected the plaintiff’s claim of standing on the ground that a corporate officer acting outside the scope of his or her authority creates a voidable contract that can still be ratified by the corporation, and it found that the hearing justice erred in denying the motion for a protective order. The Court, therefore, quashed the denial of the motion for a protective order. The Court further held that, even assuming that the plaintiff had standing to challenge the assignment, there was no basis for overturning the grant of summary judgment in favor of Litton and Deutsche Bank, and it affirmed the judgment of the Superior Court.
Kevin R. Hough v. Shawn P. McKiernan et al., No. 13-89 (January 16, 2015) | 13-89
Kevin R. Hough was severely injured when he was punched by Shawn P. McKiernan, the force of the blow causing Hough to fall backwards and strike his head on the pavement of a street. Immediately prior to this incident, McKiernan had driven by Hough on several occasions in an automobile owned by one Rita Bower, flashing the high beams and taunting Hough as he drove past. Among the defendants sued by Hough was Quincy Mutual Fire Insurance Company (Quincy), the insurer of the vehicle driven by McKiernan. Hough alleged liability under the provisions of G.L. 1956 § 31-33-6, which imputes vicarious liability upon the owner of a vehicle for its consensual use or operation. Hough appealed from a Superior Court judgment as a matter of law in favor of Quincy. Hough argued that the trial justice erred in finding that Quincy was shielded from liability under an exemption pursuant to § 31-33-6. Quincy asserted that the ruling below was proper because Hough’s injuries did not result from an accident involving the insured motor vehicle. The Supreme Court affirmed the Superior Court’s judgment as a matter of law in favor of Quincy, but it did so on different grounds from those relied on by the trial justice. The Court held that there must be a causal relationship between the operation and use of the motor vehicle and the injuries sustained by a plaintiff in order to impute liability to the vehicle owner under § 31-33-6. Because Hough failed to demonstrate such a causal connection between the vehicle and his injuries, the Supreme Court affirmed the judgment of the Superior Court
Wayne Bitgood v. Gordon Greene Post Number 27 of the American Legion, No. 2013-352 (January 16, 2015) | 13-352
A barroom altercation led to a jury verdict awarding $448,130 in damages to the plaintiff, Wayne Bitgood, on his negligence claim against Gordon Greene Post Number 27 of the American Legion, the owner of the premises on which the altercation occurred. The jury also determined that the plaintiff’s own negligence was a proximate cause of his injuries and attributed twenty percent of the overall negligence to him. The Superior Court denied the defendant’s posttrial motion for a new trial and/or remittitur for reapportionment of the plaintiff’s comparative negligence. The defendant appealed the Superior Court judgment, contending that the trial justice erred by denying the motion. The Supreme Court upheld the denial of the defendant’s motion because the trial justice properly considered the motion and neither overlooked nor misconceived material evidence. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
Patricia Pacheco v. Nestor Marulanda, No. 13-318 (January 14, 2015) | 13-318
The defendant, Nestor Marulanda, appealed a Family Court order modifying his visitation with the parties’ minor child. After the defendant was charged with breaking and entering the plaintiff’s home and pilfering her jewelry, a consent order was entered that granted the defendant supervised visitation with the child. The consent order directed that the supervision was to be provided by the defendant’s parents. Subsequently, the plaintiff filed an expedited motion to suspend the defendant’s visitation, alleging that the defendant’s visitations had been unsupervised in direct contravention of the consent order. At a hearing held by a justice of the Family Court, the defendant conceded to three separate incidents when he was with the minor child, unsupervised by his parents. As a result, the Family Court found the defendant in contempt of the consent order and modified the defendant’s visitation rights to require that any and all visitation take place at the courthouse. On appeal, the defendant argued that the hearing justice abused his discretion in modifying his visitation. Specifically, the defendant argued that the hearing justice erred because the consent order could have easily been misconstrued by him. Further, the defendant argued that the hearing justice erred in finding him in contempt because he believed his visitation did not need to be supervised. Finally, the defendant appealed the remedy that was imposed following the hearing justice’s finding of contempt. The Supreme Court held that the consent order was valid and enforceable. Next, the Supreme Court held that the hearing justice properly exercised his discretion when he found the defendant in contempt as a result of his engaging in unsupervised visitations. Finally, the Supreme Court held that the remedy imposed by the hearing justice was within his bounds of discretion and contemplated the best interests of the child. Accordingly, the Supreme Court affirmed the order of the Family Court.
Ann Marie DiLibero v. Mortgage Electronic Registration Systems, Inc., et al., No. 13-190 (January 14, 2015) | 13-190
The plaintiff, Ann Marie DiLibero, appealed a Superior Court judgment dismissing her complaint against the defendants Mortgage Electronic Registration Systems (MERS), UBS Real Estate Securities, Inc. (UBS), USA Residential Properties (USA Residential), and Rushmore Loan Management Services, LLC (Rushmore). The plaintiff had executed a mortgage, using her Foster home as collateral, with New Century Mortgage Corporation (New Century) as the lender and MERS as the named mortgagee. In April 2007, New Century filed for bankruptcy. Approximately two years later, MERS assigned its interest in the mortgage to UBS. Likewise, UBS assigned the mortgage to USA Residential. Upon entering default for failure to make timely payments, Rushmore, USA Residential’s loan servicer, began foreclosure proceedings. The plaintiff filed an action seeking injunctive relief, a declaration that the mortgage assignments were void and the foreclosure sale was invalid, and to quiet title to the property. The defendants, in lieu of an answer, filed a motion to dismiss under Rule 12(b)(6) of the Superior Court Rules of Civil Procedure. The hearing justice granted the motion to dismiss finding that the plaintiff lacked standing to challenge the assignments of the mortgage, but that even if she had standing, the assignments were valid and the foreclosure proper. On appeal, the plaintiff advanced a number of arguments in an attempt to demonstrate why the dismissal of her complaint was premature. First, the plaintiff argued that the hearing justice did not use the correct legal standard when deciding the motion to dismiss. Next, the plaintiff argued that the hearing justice erred in dismissing her complaint because she adequately alleged that the assignments of the mortgage, from MERS to UBS and from UBS to USA Residential, were invalid. The Supreme Court concluded that, based upon the facts as alleged in the complaint, the plaintiff adequately stated a claim upon which relief may be granted. The plaintiff alleged that the assignments of the mortgage were invalid because New Century filed for bankruptcy two years before the first assignment of the mortgage was executed. As a result, the plaintiff alleged that New Century’s MERS membership had been terminated, thereby prohibiting MERS from continuing to act as its nominee to assign the mortgage. The Supreme Court found that crediting the allegations of the plaintiff’s complaint as true, when New Century filed its rejection of the executory contract with MERS, the contract was breached and its relationship with MERS was terminated; therefore, the subsequent assignment of the mortgage executed by MERS to UBS would be void ab initio because the assignor, MERS, had nothing to assign. Accordingly, the Supreme Court vacated the Superior Court’s dismissal.
Roderick A. McGarry v. Marilyn Pielech et al., No. 13-146 (January 14, 2015) | 13-146
The plaintiff, Roderick A. McGarry, appealed from the denial of his motion for a new trial after a jury verdict entered in favor of the defendant Marilyn Pielech, in her capacity as Treasurer and Finance Director of the Town of Cumberland (town), in a suit alleging age discrimination in hiring. The plaintiff contends that the town discriminated against him because of his age when making its hiring decisions for a pair of English teaching positions for the 1998-1999 school year. The plaintiff was fifty-six years of age at the time of his application and both successful candidates were under the age of forty. In pursuing his claim, the plaintiff discovered that his personnel file did not contain notes and rating sheets of his performance in his interview for those positions. The plaintiff felt that those notes would show that he was equally qualified as the younger successful candidates. The defendant never produced these interview notes, and the trial justice gave an instruction on spoliation of the evidence to the jury, allowing them to infer that the notes were harmful to the defendant’s case. Nevertheless, the jury returned a verdict for the defendant. The plaintiff sought a new trial, but his motion was denied. The plaintiff appealed that denial to the Supreme Court alleging three errors. The plaintiff argued three errors of law which he believed demanded a new trial: the failure to allow him to question witnesses about a letter the defendant’s counsel had written concerning the case, the failure to instruct the jury on a federal regulation and a state statute concerning document retention and inspection, and the failure to allow him to pursue his retaliation claim. The Supreme Court concluded that these arguments were without merit. First, the trial justice reasoned that the letter’s probative value on the discrimination claim was substantially outweighed by the danger of confusing the issues and misleading the jury. The Supreme Court found no error in the trial justice’s use of discretion and the resultant exclusion of the letters. Second, the trial justice ruled that the two laws on which the plaintiff proposed she instruct the jury were inapplicable to the case at hand and that therefore an instruction on them would not have accurately stated the law for the jury. In reviewing the record, the Supreme Court found no error in the trial justice’s ruling. Third, the plaintiff had waived further litigation of his retaliation claim when he failed to appeal a judgment as a matter of law, pursuant to Rule 50 of the Superior Court Rules of Civil Procedure, granted to the defendant on the retaliation claim after the plaintiff’s first trial. The Supreme Court demands that parties address all arguments in their briefs, or that issue will be considered waived. The plaintiff’s appeal after his first trial did not contest the judgment granted to the defendant on the retaliation claim, and therefore it was correct for the trial justice to conclude that the second trial would not contain such a claim. Accordingly, the Supreme Court affirmed the Superior Court’s denial of a new trial.
Lina Cruz v. Mortgage Electronic Registration Systems, Inc., et al., No. 12-136 (January 13, 2015) | 12-136
The defendant, Mortgage Electronic Registration Systems, Inc. (MERS), petitioned for a writ of certiorari seeking review of a Superior Court decision denying its motion for a protective order as to discovery sought by the plaintiff, Lina Cruz (Cruz). Cruz had executed a mortgage on her Johnston home with New Century Mortgage Corporation as the lender and MERS as the named mortgagee. MERS subsequently transferred its interest in the mortgage to ACT Properties, LLC (ACT Properties), which then assigned its interests in the mortgage to USA Residential Properties, LLC (USA Residential). When Cruz failed to make timely payments, Rushmore Loan Management Services, LLC, acting on behalf of USA Residential, initiated foreclosure proceedings. Cruz responded by filing an action in the Superior Court seeking a declaratory judgment, injunctive relief, an order quieting title, and compensatory damages. The complaint also sought a declaration that the assignment from MERS to ACT Properties was invalid because the signer was unauthorized. Before this Court, MERS contended that the hearing justice should have granted its motion for a protective order because Cruz had no standing to challenge the validity of an assignment to which she was neither a party nor a third-party beneficiary. MERS argued that any contention that the signer lacked the requisite authority would render the assignments, at most, voidable, instead of void. Adopting the holding of the United States Court of Appeals for the First Circuit in Wilson v. HSBC Mortgage Services, Inc., 744 F.3d 1 (1st Cir. 2014), the Supreme Court limited standing to those instances where a homeowner challenges a mortgage assignment as void. The Court reasoned that a corporate officer acting outside the scope of his or her authority creates a voidable contract that can still be ratified by the corporation. As a result, the Court held that, even if successful, Cruz’s challenge to the signer’s authority would merely render the assignment voidable at the election of one of the parties to the assignment. Because Cruz was not a party to the assignment, she lacked standing to challenge it, and her attempts to engage in corresponding discovery were barred. Having concluded that Cruz lacked standing to challenge the signer’s authority, the Court found that the hearing justice erred in denying the motion for a protective order. As such, the hearing justice’s denial of the motion for a protective order was quashed.
Virginia B. Kinder, individually and in her capacity as Trustee of the Virginia B. Kinder Trust v. Jil Westcott et al., No. 14-5 (January 12, 2015) | 14-5
This case came before the Supreme Court on December 4, 2014, pursuant to an order directing the parties to appear and show cause why the issues raised in this appeal should not summarily be decided. The plaintiff, Virginia B. Kinder, filed this action, seeking a declaratory judgment to quiet title to a right-of-way and damages for trespass. The defendant, Jil Westcott, counterclaimed that her right of access derived from an instrument expressly granting an easement appurtenant. The defendant moved for summary judgment; and, at a hearing on October 1, 2013, the Superior Court granted summary judgment: declaring that the defendant had established the existence of an express easement appurtenant. The plaintiff appealed. After hearing the arguments of counsel and examining the memoranda submitted by the parties, the Supreme Court determined that cause had not been shown and that this case could be decided without further briefing or argument. The Court held that pursuant to the express terms of the recorded instrument creating the easement, the easement was freely assignable and granted an easement appurtenant. Therefore, the Court affirmed the judgment of the Superior Court.
City National Bank, successor-in-interest to Imperial Capital Bank v. Main and West, LLC et al., No. 13-150 (January 12, 2015) | 13-150
This case came before the Supreme Court for oral argument on December 4, 2014, pursuant to an order directing the parties to appear and show cause why the issues raised in this appeal should not summarily be decided. Main and West, LLC, Thomas C. Riley, and Deborah J. Stebenne (collectively, defendants) contended that the trial justice erred in granting summary judgment in favor of City National Bank (plaintiff). The defendants assert that the trial justice erred in granting the plaintiff’s motion for summary judgment because he considered, among other documents, an exhibit that was viewed in camera, without having afforded defense counsel an opportunity to review it. After carefully reviewing the record, the Supreme Court was satisfied that this appeal could be resolved without further briefing or argument. The Court determined that it was inappropriate for the trial justice to review and rely on a document not shown to defense counsel. Accordingly, the Court vacated the judgment and remanded this case to the Superior Court with directions for the Superior Court to conduct a new hearing on the plaintiff’s motion for summary judgment, after defense counsel is afforded an opportunity to review the redacted document previously viewed in camera.
Town of North Kingstown v. International Association of Firefighters, Local 1651 AFL-CIO, et al., No. 13-44, 13-66, 13-96 (January 9, 2015) | 13-44-66-96
These consolidated appeals arise out of a decision of the Superior Court issuing various declaratory and injunctive relief in a highly contested labor dispute between the town and the union regarding the town’s decision to reorganize the platoon structure of its fire department. The Supreme Court affirmed the hearing justice’s determination that the union had waived its right to submit unresolved issues to interest arbitration. Further, the Supreme Court held that the interest arbitration panel did not have jurisdiction to decide unresolved issues between the parties or to pass upon the effects of the town’s decision to reorganize the platoon structure. In light of the union’s awareness of the town’s desire to implement the platoon structure reorganization from the prior year’s arbitration proceedings, the Union’s failure to timely comply with G.L. 1956 § 28-9.1-13, the town’s formal proposal of the platoon structure reorganization during bargaining, and the union’s failure to timely submit unresolved issues to interest arbitration pursuant to § 28-9.1-7, the Supreme Court held that the town’s actions in implementing the platoon structure reorganization were lawful. Therefore, the Supreme Court vacated the injunction that purported to prevent the platoon structure reorganization. Accordingly, the Supreme Court affirmed in part and reversed in part the judgment of the Superior Court.
Theodore J. Fabrizio, Jr. v. City of Providence et al., Stephen J. Deninno, Jr. v. City of Providence et al., No. 12-157 (December 19, 2014) | 12-157
The petitioners, former Providence Mayor Vincent A. Cianci, Jr. and former Chief of the Providence Fire Department James Rattigan, sought review on certiorari of an order by the Superior Court denying without prejudice their motion for summary judgment. The underlying dispute arose after the respondents, Theodore J. Fabrizio, Jr. and Stephen J. Deninno, two Providence firefighters, objected to orders from the Fire Department that they serve as part of the crew of a fire engine in the 2001 Pride Parade. Following their unwilling participation in the parade, the respondents sued the petitioners, as well as the City of Providence, on a variety of state and federal claims. Mayor Cianci and Chief Rattigan moved for summary judgment on the surviving two of those claims (regarding freedom of religion, speech, and association), invoking the venerable doctrine of qualified immunity from suit. The Superior Court held that further development of the pertinent facts was warranted; accordingly, it denied the motion for summary judgment, but it did so without prejudice. The Supreme Court held that the requirement that the respondents participate in the parade as public servants carrying out a regular work assignment was not a deprivation of their constitutional rights. Therefore, since no deprivation of a constitutional right occurred, the petitioners prevailed as a matter of law without it being necessary to address whether they were qualifiedly immune from suit. The Superior Court was directed to enter judgment in favor of the petitioners.
Ann Marie Maguire v. City of Providence et al., No. 13-304 (November 28, 2014) | 13-304
The plaintiffs, Emond Plumbing & Heating, Inc. (Emond) and Tecta America New England, LLC (Tecta), appealed a Superior Court judgment that granted the motion of the defendant, BankNewport, for summary judgment and denied the plaintiffs’ cross-motion for summary judgment. The plaintiffs contracted with a general contractor to act as subcontractors on a construction project for the landowner. During the course of the project, the landowner defaulted on its loan obligations. As a result, the defendant reversed a disbursement of loan proceeds to the landowner that was intended to compensate the plaintiffs for their work. Thereafter, the defendant foreclosed on the property, purchased the building at the foreclosure sale, including the improvements thereon, and decided to use the property as its corporate headquarters. The plaintiffs filed suit against the defendant seeking to recover under the theory of unjust enrichment. On appeal, the plaintiffs argued that the Superior Court erred when it analyzed their claims under the Uniform Commercial Code (UCC) and the equitable subordination framework applicable to priority disputes between secured and unsecured creditors. Instead, the plaintiffs argued that their claims should have been analyzed under the theory of unjust enrichment. The plaintiffs averred that they have sufficiently demonstrated that they conferred a benefit upon the defendant, that the defendant appreciated the benefit, and that the defendant’s acceptance of the benefit, without payment, would be inequitable and unjust. The Supreme Court determined that the case law on unjust enrichment was dispositive of the instant action; therefore, there was no need to address the plaintiffs’ first argument. Next, the Supreme Court assumed, without deciding, that the plaintiff had satisfied the first two prongs of the unjust enrichment analysis. Thus, the Supreme Court stated that the third prong of the analysis—whether it would be inequitable for the defendant to retain any benefit without paying for the value thereof—was dispositive of the instant action. The Supreme Court held that because of the absence of a contractual relationship between the plaintiffs and the defendant, as well as the lack of any allegation that the defendant engaged in any type of misconduct or fraud, the defendant’s retention of the property, including the improvements thereon, was not inequitable. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
Emond Plumbing and Heating, Inc., et al., v. Bank Newport, No. 13-212 (November 28, 2014) | 13-212
The plaintiffs, Emond Plumbing & Heating, Inc. (Emond) and Tecta America New England, LLC (Tecta), appealed a Superior Court judgment that granted the motion of the defendant, BankNewport, for summary judgment and denied the plaintiffs’ cross-motion for summary judgment. The plaintiffs contracted with a general contractor to act as subcontractors on a construction project for the landowner. During the course of the project, the landowner defaulted on its loan obligations. As a result, the defendant reversed a disbursement of loan proceeds to the landowner that was intended to compensate the plaintiffs for their work. Thereafter, the defendant foreclosed on the property, purchased the building at the foreclosure sale, including the improvements thereon, and decided to use the property as its corporate headquarters. The plaintiffs filed suit against the defendant seeking to recover under the theory of unjust enrichment. On appeal, the plaintiffs argued that the Superior Court erred when it analyzed their claims under the Uniform Commercial Code (UCC) and the equitable subordination framework applicable to priority disputes between secured and unsecured creditors. Instead, the plaintiffs argued that their claims should have been analyzed under the theory of unjust enrichment. The plaintiffs averred that they have sufficiently demonstrated that they conferred a benefit upon the defendant, that the defendant appreciated the benefit, and that the defendant’s acceptance of the benefit, without payment, would be inequitable and unjust. The Supreme Court determined that the case law on unjust enrichment was dispositive of the instant action; therefore, there was no need to address the plaintiffs’ first argument. Next, the Supreme Court assumed, without deciding, that the plaintiff had satisfied the first two prongs of the unjust enrichment analysis. Thus, the Supreme Court stated that the third prong of the analysis—whether it would be inequitable for the defendant to retain any benefit without paying for the value thereof—was dispositive of the instant action. The Supreme Court held that because of the absence of a contractual relationship between the plaintiffs and the defendant, as well as the lack of any allegation that the defendant engaged in any type of misconduct or fraud, the defendant’s retention of the property, including the improvements thereon, was not inequitable. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
Torrado Architects v. Rhode Island Department of Human Services, No. 13-274 (November 25, 2014) | 13-274
This appeal came before the Supreme Court on October 30, 2014, pursuant to an order directing the parties to appear and show cause why the issues raised in this appeal should not be summarily decided. Subsequent to the confirmation of an arbitration award regarding the administrative appeal by the plaintiff, Torrado Architects (Torrado), of a decision of the state’s Chief Purchasing Officer, Torrado filed another petition to compel arbitration against the defendant, Rhode Island Department of Human Services (DHS), for equitable claims. The trial justice determined that Torrado’s successive petition to compel arbitration was barred by the doctrine of res judicata, and he entered judgment in favor of DHS. The plaintiff timely appealed the trial justice’s decision. The Supreme Court determined that cause had not been shown and affirmed the judgment of the Superior Court.
Deborah Thornley v. Community College of Rhode Island et al., No. 12-283 (November 24, 2014) | 12-283
The plaintiff in this disability discrimination case, Deborah Thornley, appealed from a Superior Court judgment in favor of the defendants, Community College of Rhode Island, Anita Creamer, Doris Fournier, and the Board of Governors for Higher Education. The plaintiff was enrolled in the nursing program at the Community College of Rhode Island during the 2003-2004 academic year, while allegedly suffering from chronic headaches, which she treated with the medication Percocet. During the spring semester of 2004, the plaintiff left the nursing program. She subsequently filed a civil action against the defendants, claiming that she had been “dropped” from the nursing program because of her disability. The jury, however, after an eleven-day trial, reached a verdict for the defendants, finding that the plaintiff had failed to prove that she was disabled. The plaintiff argued on appeal that the trial justice erred by: (1) admitting into evidence a medical report prepared by a neurologist who treated the plaintiff four years after she left the nursing program; (2) excusing a juror on the fourth day of trial; and (3) informing the jury that some of the plaintiff’s claims had been dismissed as a matter of law after the close of evidence. The Supreme Court held that the trial justice did not err by admitting the medical report into evidence because the report was relevant to the issue of whether the plaintiff was disabled. The Supreme Court further held that the trial justice was acting well within the parameters of her broad discretionary authority when she excused the juror. The Supreme Court held that the plaintiff’s final argument on appeal was waived because the plaintiff’s counsel at trial failed to object to the trial justice’s statement at the time it was made. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
John Wells v. R. Suzanne Smith et al., No. 13-273 (November 24, 2014) | 13-273
This case arose out of claims of negligence brought by the plaintiff, John Wells (plaintiff), alleging that R. Suzanne Smith (Smith) and Michael Ead (Ead) (collectively, defendants), negligently caused the plaintiff’s injuries. The Supreme Court heard oral argument on October 30, 2014, pursuant to an order directing the parties to appear and show cause why the issues raised in this appeal should not summarily be decided. A justice of the Superior Court had granted summary judgment in favor of the defendants. The trial justice determined that the plaintiff had conceded all counts except for counts two, the negligent-hiring claim, and seven, the negligent design, construction, and inspection claim. With respect to counts two and seven, the trial justice held that Smith could not be found negligent in hiring Ead, because she did not owe a legal duty of care to the plaintiff. The trial justice also found that Ead owed no duty of care to the plaintiff. Subsequently, the plaintiff timely appealed. After hearing the arguments of counsel and reviewing the memoranda of the parties, the Court was satisfied that cause had not been shown and affirmed the judgment of the Superior Court. Justice Flaherty did not participate.
State v. Kevin Storey, No. 12-327 (November 24, 2014) | 12-327
The defendant, Kevin Storey, appealed from a Superior Court judgment of conviction for one count of assault with a dangerous weapon and one count of simple assault and battery. The defendant was sentenced to a term of fifteen years at the Adult Correctional Institutions, with five years to serve and ten years suspended, with probation. On appeal, the defendant argued that the trial justice erred by: (1) denying his motions for judgment of acquittal and new trial; (2) not allowing him to cross-examine the complaining witness concerning custody issues involving her sons; and (3) imposing an illegal sentence. The Supreme Court upheld the denial of the defendant’s motions for judgment of acquittal and new trial because the trial justice properly considered the defendant’s motion for a new trial and neither overlooked nor misconceived material evidence. The Supreme Court also held that the trial justice had not abused her discretion when she limited the scope of the defendant’s cross-examination to exclude the subject of custody issues with the complaining witness’s two eldest sons. The Supreme Court held that the sentencing issue was not properly before it for review because the defendant had not challenged the sentence in the Superior Court and failed to present extraordinary circumstances that compelled review by this Court. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
Pawtucket Redevelopment Agency v. Patricia Brown, Nos. 13-132, 14-164 (November 21, 2014) | 13-132-14-164
The defendant, Patricia Brown, appealed from a Superior Court ruling granting the plaintiff, Pawtucket Redevelopment Agency, its motion for a new trial and the setting aside of a jury verdict in favor of the defendant on her counterclaim against the PRA. The plaintiff also appealed the denial of its renewed motion for judgment as a matter of law. Having found that the trial justice appropriately carried out her duties under Rule 59 of the Superior Court Rules of Civil Procedure, the Supreme Court affirmed the decision to grant a new trial and set aside the jury verdict on the defendant’s counterclaim. Additionally, the Supreme Court declined to address the merits of the plaintiff’s appeal because the plaintiff’s notice of appeal was not timely filed.
Patricia Breggia et al. v. Mortgage Electronic Registration Systems, Inc., et al., No. 13-79 (November 21, 2014) | 13-79
The plaintiffs, Patricia Breggia and Frank Breggia, Jr., appealed from the Superior Court entry of summary judgment against them and in favor of the defendants Mortgage Electronic Registration Systems, Inc. (MERS) and OneWest Bank, FSB (OneWest). The plaintiffs had executed a mortgage on their Johnston home with American Mortgage Network, Inc. (AmNet) as the lender and MERS as the named mortgagee. MERS subsequently transferred its interest in the mortgage to OneWest; and, when the plaintiffs failed to make timely payments, OneWest initiated foreclosure proceedings. The plaintiffs responded by filing an action in the Superior Court seeking a declaratory judgment, injunctive relief, and compensatory damages. The complaint sought a declaration that the assignment from MERS to OneWest was invalid, and it also sought to quiet title to the property. On appeal, the plaintiffs contended that genuine issues of material fact existed as to the ability of MERS to serve as mortgagee without at the same time being the holder of the note, as to the validity of the assignment from MERS to OneWest, and as to the lawfulness of the foreclosure sale. The plaintiffs also claimed that the hearing justice improperly relied on previous Superior Court decisions. Citing Bucci v. Lehman Brothers Bank, FSB, 68 A.3d 1069, 1085 (R.I. 2013), the Supreme Court held that MERS was not only the nominee of the lender, but also the mortgagee with the statutory power of sale. The Court also held that the assignment from MERS to OneWest was valid and consistent with Mruk v. Mortgage Electronic Registration Systems, Inc., 82 A.3d 527, 538 (R.I. 2013). The Court further held that the foreclosure sale initiated by OneWest was lawfully noticed and conducted. Finally, the Court rejected the plaintiffs’ contention that the hearing justice improperly relied upon previous Superior Court decisions. Having concluded that these were questions of law properly settled by the hearing justice, the Court affirmed the judgment.
State v. Brian Verry, No. 11-353 (November 20, 2014) | 11-353
The defendant, Brian Verry (defendant), appealed from a judgment of conviction of one count of felony assault, for which he received a twenty-year suspended sentence with twenty years of probation; one count of simple assault, for which he received a one-year sentence to be served concurrently with the other sentence imposed; and one count of first-degree child abuse, for which he received a sentence of twenty years, with fifteen years to serve and five years suspended with five years of probation. In support of his appeal, the defendant argued that the trial justice (1) abused his discretion in refusing to grant a continuance and (2) erred and violated the defendant’s right to present a defense when the trial justice prohibited the defendant’s father from testifying in the defendant’s case-in-chief. The Supreme Court determined that the trial justice did not err and affirmed the judgment of the Superior Court.
William J. Nye v. Susan J. Brousseau et al., No. 13-302 (November 19, 2014) | 13-302
The plaintiff, William J. Nye, appealed pro se from a grant of summary judgment and dismissal in favor of the defendants, Susan J. Brousseau, individually and as trustee, Paul G. Brousseau, individually and as trustee, and The Brousseau Family Trust, concerning an action regarding a parcel of land (judgment parcel) that this Court previously affirmed belonged to the plaintiff. On appeal, the plaintiff argued that the trial justice erred in dismissing his count to quiet title for failure to comply with an order compelling the plaintiff to produce a title abstract. The plaintiff additionally argued that the trial justice was incorrect in granting summary judgment on the counts alleging negligence and fraud because the defendants improperly transferred their property to The Brousseau Family Trust. The Supreme Court held that the trial justice did not abuse her discretion in dismissing the claim to quiet title based on the plaintiff’s failure to comply with the court order, particularly after he disavowed any claim pursuant to G.L. 1956 § 34-16-2. Additionally, the Court determined that no genuine issues of material fact existed and affirmed summary judgment on the counts sounding in negligence and fraud. Accordingly, the judgment of the Superior Court was affirmed.
Rocco D'Alessio v. State of Rhode Island, No. 11-389 (November 18, 2014) | 11-389
The applicant, Rocco D’Alessio, appealed a Superior Court denial of his postconviction-relief application. On April 16, 2002, the applicant was convicted of the second-degree murder of his infant daughter, Gianna D’Alessio. The medical testimony at trial was that of Dr. Elizabeth Laposata, who gave her opinion that the infant had died due to a violent shaking. Considering the evidence that the applicant was in sole custody of the infant at the time, the jury concluded that the injuries were inflicted by the applicant and a guilty verdict was returned. The applicant was sentenced to a term of sixty years, forty years to serve in prison, with the balance suspended with probation. In 2007, the applicant filed an application for postconviction relief based on newly discovered evidence that he argued required that his conviction be vacated. This newly discovered evidence was the existence of a Dr. Richard T. Callery, a medical examiner who had worked on the infant’s autopsy file while employed on a contract basis with Rhode Island’s Office of State Medical Examiners (OSME). Doctor Callery’s testified before the original trial justice at a three-day hearing for postconviction relief in July of 2011. Doctor Callery testified that his role at OSME was to review and complete the autopsy files that had been begun and left unfinished by Dr. Samuel A. Livingstone, a medical examiner who no longer worked in the office. Doctor Callery testified that, when he viewed the D’Alessio file, he was unable to agree with the preliminary conclusion that the infant’s manner of death was homicide by a violent shaking. Doctor Callery testified that this was due to the poor condition of the file, including its slides and photographs. However, Dr. Callery was not able to provide a definite conclusion as to the manner of death, nor did he dispute that the file could have been completed in order to confirm the conclusion that the manner of death was a homicide. In ruling on the application, the hearing justice noted that Dr. Laposata’s trial testimony was definite in her conclusions, backed by her medical experience, and based on a complete file. Because Dr. Callery’s testimony was not of the type that would ultimately change the verdict at a new trial, the hearing justice denied the application for postconviction relief. On appeal, the applicant advanced three arguments. First, applicant contended the hearing justice was clearly erroneous when he ruled that the newly discovered evidence was not material and would not change the verdict at trial. Second, he alleged the court erred by raising and denying, sua sponte, a claim of ineffective assistance of counsel. Third, applicant argued that his right to due process was violated when the state withheld evidence from the defense in violation of the applicant’s constitutional rights as set forth in Brady v. Maryland, 373 U.S. 83 (1963). The Supreme Court concluded that the first argument was without merit and that the second and third arguments were not properly before this Court because they were not raised in the postconviction-relief hearing below. Doctor Callery’s testimony was simply not strong enough to warrant relief and instead was of such a vague and indefinite nature that it could not create a “reasonable probability of a different result.” Doctor Callery said he did not remember specifically what the file contained, failed to offer a definite conclusion, and ultimately did not provide evidence that meets this Court’s test for materiality. If Dr. Callery’s testimony were to be offered at trial alongside the testimony of Dr. Laposata, it was not of a type that would likely change the verdict at a new trial. The Court found no clear error in the hearing justice’s ruling. Accordingly, the Supreme Court affirmed the Superior Court’s denial of postconviction relief.
Wayne DeMarco et al. v. Travelers Insurance Company et al., No. 12-309 (November 18, 2014) | 12-309
The defendant, Travelers Insurance Company (Travelers), was before the Court on appeal from a Superior Court order for prejudgment interest pursuant to G.L. 1956 § 27-7-2.2, in favor of the plaintiffs, Wayne DeMarco and Leesa DeMarco, individually, as parents and legal guardians of Chayce DeMarco, a minor, and Brayden DeMarco, a minor, and as assignees of Leo H. Doire, and Virginia Transportation Corporation. This Court previously affirmed the entry of summary judgment with respect to § 27-7-2.2 liability in DeMarco v. Travelers Insurance Co., 26 A.3d 585 (R.I. 2011) (DeMarco I). On appeal, Travelers argued that the claim for interest pursuant to § 27-7-2.2 was rendered moot by the entry of a judgment satisfied order necessary to complete an assignment of claims between plaintiffs and Travelers’ insureds and thus divested the Superior Court of subject-matter jurisdiction. Furthermore, Travelers contended that the Superior Court improperly concluded on remand that the claim for interest was affirmed. The Supreme Court held that the § 27-7-2.2 claim for interest was affirmed by the Court’s prior decision. The Court concluded that the Superior Court was not divested of subject- matter jurisdiction. Additionally, the Court ruled that the judgment satisfied order did not render moot the claims assigned to plaintiffs. Accordingly, the Court affirmed the order of the Superior Court.
State v. Allen Wray, No. 13-214 (November 12, 2014) | 13-214
The defendant, Allen Wray, appealed from an order of the Superior Court denying his motion for credit for time served while awaiting trial and sentencing. In January 2006, while serving a suspended twelve-year sentence for drug-related charges, the defendant was charged and held without bail on robbery charges. In April 2006, the defendant was adjudicated a probation violator and ordered to serve the previously suspended sentence. He was convicted of the robbery charges in December 2008 and sentenced in April 2009 to ten years to serve, to run concurrently with the sentence imposed for the drug-related charges. The defendant argued that, pursuant to the provisions of G.L. 1956 § 12-19-2(a), his sentence in the robbery case should have been reduced by the number of days that he spent incarcerated between his arrest in January 2006 and his sentencing in April 2009. Alternatively, the defendant argued that he was entitled to credit for the time between his arrest in January 2006 and his probation violation adjudication in April 2006. The Supreme Court held that the defendant was entitled to credit for his time served between January 2006 and April 2006. The defendant was not, however, entitled to credit for the time he served between April 2006 and April 2009 because, during this time, he was serving the execution of the previously suspended sentence for the drug-related charges.
State v. John S. Miguel, No. 10-131 (November 10, 2014) | 10-131
The defendant, John S. Miguel, appealed pro se from a Superior Court order denying his motion to reduce what he contended was an illegal sentence imposed upon him pursuant to Rule 35 of the Superior Court Rules of Criminal Procedure in January of 1992. In the underlying criminal case, the defendant pled guilty to the second-degree murder of his wife, and he received a life sentence. On appeal, he argued: (1) that his life sentence is illegal because it exceeds the thirty-year maximum sentence for voluntary manslaughter, the crime for which the defendant felt he ought to have been sentenced, rather than second-degree murder; and (2) that the continued imposition of the life sentence is violative of the Eighth Amendment to the United States Constitution and article 1, section 8 of the Rhode Island Constitution. The Supreme Court affirmed the trial justice’s denial of the defendant’s Rule 35 motion, holding that, because life imprisonment is within the purview of Rhode Island’s statute prescribing punishments for murder and because the defendant validly entered a plea of guilty to second-degree murder, the defendant’s sentence of life imprisonment was not illegal under Rule 35. In addition, the Supreme Court held that there was no violation of the Eighth Amendment, nor was there a violation of the parallel provision of the Rhode Island Constitution, where the defendant pled guilty to the crime of second-degree murder and received a lawful sentence.
State v. Kathleen McKinnon-Conneally, No. 12-226 (November 10, 2014) | 12-226
The defendant, Kathleen McKinnon-Conneally, appealed from a Superior Court judgment finding her to be in violation of the terms of her probation and sentencing her to serve the remaining eight and one-half years of her previously suspended sentence. The defendant’s original sentence was imposed in 2010 after she pled nolo contendere to one count of second-degree robbery. The original sentence was for ten years at the Adult Correctional Institutions (ACI), with eighteen months to serve, which term to serve was stayed pending her completion of mental health and substance abuse counseling, and eight and one-half years suspended, with probation. The stay was removed and the defendant was incarcerated at the ACI to serve the eighteen-month portion of the sentence. Shortly after her release from the ACI, the defendant was arrested on charges of first-degree robbery and conspiracy to commit first-degree robbery. The defendant was presented to the Superior Court as a probation violator pursuant to Rule 32(f) of the Superior Court Rules of Criminal Procedure. The Superior Court found that the defendant had violated the terms of her probation and ordered her to serve the entire eight and one-half years of the previously suspended portion of her sentence. The defendant subsequently pled nolo contendere to the charges of first-degree robbery and conspiracy to commit first-degree robbery. On appeal, the defendant argued that the hearing justice abused his discretion when he ordered her to serve the entire remaining suspended portion of her original sentence. The defendant claimed that the hearing justice ignored the sentencing benchmark for the 2010 conviction for second-degree robbery, the defendant’s mental health diagnoses, and the defendant’s substance abuse problems. After carefully considering the record in light of the hearing justice’s broad discretion to determine the extent to which a suspended sentence will be executed, if at all, the Supreme Court was satisfied that the hearing justice did not abuse his discretion. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
Simcha Berman et al. v. Laura Sitrin, in her capacity as Finance Director for the City of Newport et al., Nos. 11-266, 12-77, 12-116 (November 10, 2014) | 11-266-12-77-12-116
The plaintiffs, Simcha and Sarah Berman, appealed from a judgment in favor of the defendant, the State of Rhode Island, after a jury trial declaring that the defendant was not negligent. The plaintiffs also appealed the denial of their motions for judgment as a matter of law, a new trial, and to vacate judgment. The defendant cross-appealed the denial of its motion for judgment as a matter of law. The plaintiffs assigned error to various rulings over the course of the trial. In particular, plaintiffs argued that there was error (1) in the trial justice’s refusal to grant a change of venue or venire; (2) in the manner in which a jury view was conducted; (3) in the refusal to admit into evidence a letter written by the then-president of a nearby college; (4) in the jury being informed that a settling joint tortfeasor had liability insurance pursuant to Rule 411 of the Rhode Island Rules of Evidence for the purposes of proving ownership and control; (5) in the trial justice’s adherence to our prior decision in this case, and in improperly instructing the jury. The Court held that there was no error in the trial justice’s rulings that warranted reversal. The plaintiffs also argued that the trial justice should have granted plaintiffs’ motions for judgment as a matter of law, a new trial, or to vacate judgment. The Court held that the trial justice properly denied these motions. Having affirmed the jury verdict in favor of the defendant, the Court declined to entertain the arguments raised in the state’s cross-appeal.
Timothy Raiche d/b/a T. Raiche Builders v. Timothy W. Scott et al., No. 12-189, 12-190 (October 31, 2014 | 12-189-12-190
These consolidated appeals came before the Supreme Court on October 2, 2014, pursuant to an order directing the parties to appear and show cause why the issues raised in these appeals should not be summarily decided. After a bench trial, a justice of the Superior Court declared that the defendants, Timothy W. and Pamela J. Scott (the defendants), owed the plaintiff, Timothy Raiche (the plaintiff) d/b/a T. Raiche Builders, $5,455.50 in damages and further found that the defendants were responsible for prejudgment interest on the amount of an offer of judgment that had been deposited in the Registry of the Superior Court, in accordance with Rule 68(b)(3) of the Superior Court Rules of Civil Procedure. The defendants timely appealed the trial justice’s decision to award prejudgment interest on the amount of the offer of judgment. The plaintiff cross-appealed the trial justice’s damages award. The Supreme Court determined that cause had not been shown and thus, denied and dismissed the appeals of both parties and affirmed the judgment.
Federal National Mortgage Association v. Etta E. Malinou et al., No. 13-179 (October 20, 2014) | 13-179
The defendant, Martin Malinou, appealed a Superior Court judgment that awarded the plaintiff, Federal National Mortgage Association (Fannie Mae), possession of premises in Providence (the property). The defendant’s mother, Etta E. Malinou, had owned the property and had executed a “reverse mortgage” thereon. After Mrs. Malinou’s death, the defendant inherited the property and payment of the note executed by Mrs. Malinou was demanded in full. No payments were made. As a result, the property was sold at a foreclosure sale. Thereafter, the property was conveyed to the plaintiff, which filed a trespass and ejectment action in the District Court. The case was transferred to the Superior Court for trial where judgment entered in favor of the plaintiff. On appeal, the defendant raised five arguments: (1) The Superior Court did not have personal or subject matter jurisdiction over the controversy because there was no service on the estate; (2) deference should not be given to the trial justice’s findings of fact because they were based on documentary evidence; (3) the trial justice erred when she required clear and convincing evidence to rebut the presumption in favor of Fannie Mae; (4) the trial justice erred when she failed to enforce the subpoenas duces tecum issued upon Lender Processing Services, Inc. and Bank of America; and (5) an August 2012 tax-sale deed in favor of Rookies Real Estate divested Fannie Mae of the right to possess the property. The Supreme Court held that the personal jurisdiction argument was waived because it was not raised in the Superior Court. The Supreme Court also concluded that the trial court was vested with subject matter jurisdiction because the defendant answered the complaint and appeared in court. With respect to the defendant’s second argument, the Supreme Court held that it was well established that deference be given to the trial justice’s decision when sitting without a jury. Next, the Supreme Court upheld the trial justice’s finding that the defendant failed to rebut the presumption that Fannie Mae was entitled to possession of the property. Further, the Supreme Court held that the trial justice’s decision to not enforce the subpoenas that were overbroad and issued on the eve of trial was not an abuse of discretion. Finally, the Supreme Court held that the defendant’s argument concerning the tax-sale deed was meritless because the plaintiff was within the redemption period. Accordingly, the Supreme Court affirmed the judgment of the Superior Court.
Desmond A. Leone v. Mortgage Electronic Registration Systems, et al., No. 13-59 (October 20, 2014) | 13-59
The plaintiff, Desmond A. Leone, appealed a Superior Court entry of summary judgment against him and in favor of the defendants Mortgage Electronic Registration Systems (MERS), Equity One, Inc. (Equity One), and Assets Recovery Center Investments, LLC (ARC). The plaintiff had executed a mortgage, using his Johnston home as collateral, with Equity One as the lender and MERS as the named mortgagee. MERS later assigned its interest in the mortgage to ARC. Upon entering default for failure to make timely payments, ARC began foreclosure proceedings and the home was sold in November of 2009. The plaintiff filed an action for declaratory relief in Providence County Superior Court seeking declarations that the assignment of his mortgage from MERS to ARC was invalid and to quiet title to the property. The defendants filed a motion to dismiss under Rule 12(b)(6) of the Superior Court Rules of Civil Procedure and the hearing justice converted the motion to one for summary judgment when he considered materials provided to him by the parties that were outside of the pleadings. In granting summary judgment for the defendants, the hearing justice declared that there were no genuine issues of material fact and that the defendants were entitled to judgment as a matter of law. On appeal, the plaintiff advanced a number of arguments. First, the plaintiff contested the hearing justice’s conversion of the motion to dismiss to a motion for summary judgment. Next, the plaintiff contended that summary judgment was incorrectly granted to the defendants because there were genuine issues of material fact. The plaintiff argued that the assignment of the mortgage from MERS to ARC was invalid, that the foreclosure by ARC was improper, and that the hearing justice improperly relied on other Superior Court decisions. The Supreme Court concluded that these arguments were without merit. Rule 12(b) says that if a hearing justice considers materials outside the pleadings the motion shall be converted to one for summary judgment. Here, both the plaintiff and the defendants submitted extraneous documents and should have been on notice of the motion’s conversion. On the remaining points, the Supreme Court found on facts similar to those in Bucci v. Lehman Brothers Bank, FSB, 68 A.3d 1069, 1085 (R.I. 2013), MERS was the mortgagee with the Statutory Power of Sale and not simply the nominee of the lender. The assignment of the mortgage from MERS to ARC was valid and consistent with the Court’s decision in Mruk v. Mortgage Electronic Registration Systems, Inc., 82 A.3d 527 (R.I. 2013). Further, the limited power of attorney from Equity One to ARC gave ARC the rights of the lender in addition to the rights of mortgagee. Therefore, the foreclosure by ARC on the property was proper. These were questions of law properly settled by the hearing justice. Accordingly, the Supreme Court affirmed the Superior Court’s grant of summary judgment.
Kevin R. Hough v. Shawn P. McKiernan et al., No. 13-90 (October 17, 2014) | 13-90
The defendant, Shawn P. McKiernan, appealed from a Superior Court ruling granting his motion for remittitur and awarding the plaintiff, Kevin R. Hough, damages of $925,000. On appeal, the defendant argued that the award of $925,000 was excessive, punitive, and shocked the conscience. The Supreme Court held that the trial justice conducted the appropriate analysis and did not overlook or misconceive material evidence in ruling on the motion for a remittitur and/or a new trial. The Court determined that the trial justice weighed the evidence and testimony properly before coming to the conclusion that the plaintiff’s medical expenses, permanent injuries, and pain and suffering justified an award of $925,000. Accordingly, the Court affirmed the judgment.
In re Estate of Ann Marie Picillo et al., No. 11-262 (October 15, 2014) | 11-262
In this will contest, Michael J. Picillo (contestant), a nephew and heir-at-law of Ann Marie Picillo (the decedent), appealed a Superior Court judgment affirming the Probate Court’s decision to admit the decedent’s will to probate. On appeal, contestant, who was before the Court pro se, argued that the trial justice erred by: (1) failing to consider whether the will was executed in compliance with G.L. 1956 § 33-5-5; (2) concluding that the will was not the product of undue influence; (3) finding the decedent had the requisite testamentary capacity to execute the will; and (4) failing to make appropriate findings of fact required by Rule 52(a) of the Superior Court Rules of Civil Procedure.

Compliance Details
javascript:commonShowModalDialog('{SiteUrl}'+ '/_layouts/15/itemexpiration.aspx' +'?ID={ItemId}&List={ListId}', 'center:1;dialogHeight:500px;dialogWidth:500px;resizable:yes;status:no;location:no;menubar:no;help:no', function GotoPageAfterClose(pageid){if(pageid == 'hold') {STSNavigate(unescape(decodeURI('{SiteUrl}'))+ '/_layouts/15/hold.aspx' +'?ID={ItemId}&List={ListId}'); return false;} if(pageid == 'audit') {STSNavigate(unescape(decodeURI('{SiteUrl}'))+ '/_layouts/15/Reporting.aspx' +'?Category=Auditing&backtype=item&ID={ItemId}&List={ListId}'); return false;} if(pageid == 'config') {STSNavigate(unescape(decodeURI('{SiteUrl}'))+ '/_layouts/15/expirationconfig.aspx' +'?ID={ItemId}&List={ListId}'); return false;}}, null);
0x0
0x1
ContentType
0x01
898
Document Set Version History
/_layouts/15/images/versions.gif?rev=23
javascript:SP.UI.ModalDialog.ShowPopupDialog('{SiteUrl}'+ '/_layouts/15/DocSetVersions.aspx' + '?List={ListId}&ID={ItemId}')
0x0
0x0
ContentType
0x0120D520
330
Send To other location
/_layouts/15/images/sendOtherLoc.gif?rev=23
javascript:GoToPage('{SiteUrl}' + '/_layouts/15/docsetsend.aspx' + '?List={ListId}&ID={ItemId}')
0x0
0x0
ContentType
0x0120D520
350